function [f,g]=dp_clogit(para,LLS)
% Conditional logit log likelihood
% - LLS.id is the panel unit, consecutive from 1 to max(id);
% - LLS.m is the choice id within the panel unit, consecutive from 1 to 
%   max(m), need not be balanced across units
% - LLS.y is outcome corresponding to chosen choice (0 or 1)
% - LLS.u_x is matrix of covariates corresponding to u
% - LLS.EW_x is matrix of covariates corresponding to EW

Nj=LLS.Nj;				% number of model parameters	
Nk=LLS.Nk;              % number of splines in value function
para_u=para(1:Nj);		% model parameters (utility function)
para_W=para(Nj+1:end);	% spline parameters in value function
delta=LLS.delta;
Nobs=LLS.Nobs;
sumwt=sum(LLS.wt);
assert(size(para,1)==Nj+Nk&&size(para,2)==1, ...
    'Error: para vector incorrect size');
maxm=max(LLS.m);

assert(ismatrix(LLS.u_x) && size(LLS.u_x,2)==Nj, ...
    '# of variables in u does not match # of coefficients');
assert(ismatrix(LLS.EW_x) && size(LLS.EW_x,2)==Nk, ...
    '# of variables in EW does not match # of coefficients');
assert(ismatrix(LLS.W_x) && size(LLS.W_x,2)==Nk, ...
    '# of variables in W does not match # of coefficients');
assert(size(unique(LLS.id),1)==Nobs, ...
    '# of unique IDs does not match stated Nobs');

num=exp(LLS.u_x*para_u + delta *LLS.EW_x*para_W);
den=zeros(Nobs,1);
for m=1:maxm
    ids=LLS.id(LLS.m==m);
    den(ids)=num(LLS.m==m)+den(ids);
end

% Log likelihood
f=-sum(LLS.wt.*log(num(LLS.y)./den))/sumwt;

% Gradient
g=-sum(repmat(LLS.wt(LLS.id),1,Nj+Nk) .* ...
    [LLS.u_x, delta*LLS.EW_x] .* ...
    repmat(LLS.y-num./den(LLS.id),1,Nj+Nk))/sumwt;
