function [para,fval,delta,lc_est,lc_se] = ...
    dp_main_fun(inputfile,outputfile,varargin)

p = inputParser;
addRequired(p,'inputfile',@ischar);
addRequired(p,'outputfile',@ischar);
addParameter(p,'idname','groupid',@ischar);
addParameter(p,'yname','choice',@ischar);
addParameter(p,'mname','choicenum',@ischar);
addParameter(p,'wtname','',@ischar);
addParameter(p,'delta',1,@real);
addParameter(p,'cf',false,@boolean);
addParameter(p,'parafile','',@ischar);
addParameter(p,'eoscon',false,@boolean);
addParameter(p,'eosvar','',@ischar);
addParameter(p,'fvalfile','',@ischar);
addParameter(p,'lncom','',@ischar);
addParameter(p,'lcoutfile','',@ischar);

parse(p,inputfile,outputfile,varargin{:})
disp(['Input file: ',p.Results.inputfile])
disp(['Output file: ',p.Results.outputfile])

if ~isempty(p.UsingDefaults)
   disp('Using defaults: ')
   disp(p.UsingDefaults)
end

if p.Results.cf==true,
    assert(~strcmp(p.Results.parafile,''),'Error: must specify para with cf');
    assert(strcmp(p.Results.lncom,''),'Error: lncom not valid with cf');
    LLS.eoscon=p.Results.eoscon;
    if LLS.eoscon
        assert(~strcmp(p.Results.eosvar,''), ...
            'Error: must specify eosvar with eoscon');
    end
else
    assert(~p.Results.eoscon&&strcmp(p.Results.eosvar,''), ...
        'Error: cannot specify eoscon=true or eosvar if cf=false');
    LLS.eoscon=false;
end;
if ~isempty(p.Results.lncom),
    assert(~isempty(p.Results.lcoutfile), ...
        'Error: Must specify lcoutfile with lncom');
end;

if ismac
    root='~/Dropbox';
else root='C:/Users/Chand04.PCOR9/Documents';
end;
workingdir=strcat(root,'FILL IN');
% Set this directory to be the parent directory of ${Code} and ${Output}
% defined in the Stata file setdir.do
path(path,strcat(workingdir,'/Code'));
delimiterIn = ',';
headerlinesIn = 1;

LLS.delta=p.Results.delta;

if ~isempty(inputfile),
    idname=p.Results.idname;
    yname=p.Results.yname;
    mname=p.Results.mname;
    wtname=p.Results.wtname;
    A = importdata(strcat(workingdir,'/Data/',inputfile),delimiterIn, ...
        headerlinesIn);
    id_cols=cellfun(@(x) strcmp(x,idname), A.colheaders);
    y_cols=cellfun(@(x) strcmp(x,yname), A.colheaders);
    m_cols=cellfun(@(x) strcmp(x,mname), A.colheaders);
    u_x_cols=cellfun(@(x) ~isempty(strfind(x, 'u_')), A.colheaders);
    W_x_cols=cellfun(@(x) ~isempty(strfind(x, 'w_'))& ...
        isempty(strfind(x,'Ew_')), A.colheaders);
    EW_x_cols=cellfun(@(x) ~isempty(strfind(x, 'Ew_')), A.colheaders);
    eos_cols=cellfun(@(x) strcmp(x,p.Results.eosvar), A.colheaders);
    LLS.id=A.data(:,id_cols);
    LLS.y=logical(A.data(:,y_cols));
    LLS.m=A.data(:,m_cols);
    LLS.u_x=A.data(:,u_x_cols);
    LLS.W_x=A.data(LLS.m==1,W_x_cols);
    LLS.EW_x=A.data(:,EW_x_cols);
    if LLS.eoscon,
        LLS.eos=logical(A.data(LLS.m==1,eos_cols));
    end;

    LLS.Nobs=size(unique(LLS.id),1);
    LLS.Nj=size(LLS.u_x,2);
    LLS.Nk=size(LLS.W_x,2);
    if ~isempty(wtname),
        wt_cols=cellfun(@(x) strcmp(x,wtname), A.colheaders);
        LLS.wt=A.data(LLS.m==1,wt_cols);
        LLS.haswt=true;
    else
        LLS.wt=ones(LLS.Nobs,1);
    end
    LLS.sumwt=sum(LLS.wt);
end;

if ~isempty(p.Results.lncom),
    lcmat=csvread(p.Results.lncom);
    assert(size(lcmat,2)==(LLS.Nj+LLS.Nk), ...
        'Error: lncom matrix with incorrect # of columns');
end;

assert(LLS.Nobs==max(LLS.id)&&min(LLS.id)==1, ...
    'Error: IDs not numbered consecutively from 1 to Nobs');
assert(LLS.Nk==size(LLS.EW_x,2),'Error: Nk not the same in W_* and EW_*');
assert(LLS.Nobs==size(LLS.W_x,1),'Error: rows in W_x ~= Nobs');

if p.Results.cf==true,
    fileID = fopen(p.Results.parafile,'r');
    para_input = fscanf(fileID,'%f');
    assert(size(para_input,1)==(LLS.Nj+LLS.Nk),...
        'Error: parafile incorrect size');
    fclose(fileID);
    para_W0 = para_input((1+LLS.Nj):end);
    LLfn = @(para)dp_nlls(para,para_input,LLS);
    
    options = optimoptions(@fminunc,'SpecifyObjectiveGradient',true, ...
        'Algorithm','quasi-newton','CheckGradients',false,...
        'Display','iter','UseParallel',false);
    tic;
    [para_W,fval]=fminunc(LLfn,para_W0,options);
    toc;
    para=[para_input(1:LLS.Nj);para_W];
else
    para0 = zeros(LLS.Nj+LLS.Nk,1);
    rng(0,'twister'); 
    LLfn = @(para)dp_clogit(para,LLS);
    confn = @(para)dp_confn(para,LLS);
    options = optimoptions(@fmincon,'SpecifyConstraintGradient',true, ...
        'SpecifyObjectiveGradient',true,'FiniteDifferenceType','central', ...
        'CheckGradients',false,'Algorithm','sqp','Display','iter', ...
        'UseParallel',false);
    tic;
    [para,fval]=fmincon(LLfn,para0,[],[],[],[],[],[],confn,options);
    toc;
    if ~isempty(p.Results.lncom),
        % Calculate Hessian using fminunc, given inaccurate Hessian under
        % fmincon (http://www.mathworks.com/help/optim/ug/hessian.html)
        options = optimoptions(@fminunc,'SpecifyObjectiveGradient',true, ...
            'Algorithm','quasi-newton','CheckGradients',false,...
            'Display','none','UseParallel',false,'MaxIterations',0);
        [~,~,~,~,~,hessian] = fminunc(LLfn,para,options);
        lc_est=lcmat*para;
        lc_se=sqrt(diag(lcmat*(inv(hessian)/LLS.Nobs)*lcmat'));
    end;
end;

delta=LLS.delta;
save(strcat(workingdir,'/Output/',outputfile), ...
    'delta','-ascii','-tabs');
save(strcat(workingdir,'/Output/',outputfile), ...
    'para','-append','-ascii','-tabs');
if ~strcmp(p.Results.fvalfile,''),
    tosave=[delta,fval]; %#ok<NASGU>
    save(strcat(workingdir,'/Output/',p.Results.fvalfile), ...
        'tosave','-append','-ascii','-tabs');
end;
if ~isempty(p.Results.lncom),
    tosave=[LLS.Nobs,size(LLS.id,1); ...
        delta,fval*LLS.sumwt; lc_est,lc_se]; %#ok<NASGU>
    save(strcat(workingdir,'/Output/',p.Results.lcoutfile), ...
        'tosave','-ascii','-tabs');
end;