function [obj,g]=dp_nlls(para_W,para0,LLS)
% Nonlinear least squares for counterfactuals (very similar to
% dp_confn.m)
% - LLS.id is the panel unit, consecutive from 1 to max(id);
% - LLS.m is the choice id within the panel unit, consecutive from 1 to 
%   max(m), need not be balanced across units
% - LLS.y is outcome corresponding to chosen choice (0 or 1)
% - LLS.u_x is matrix of covariates corresponding to u
% - LLS.EW_x is matrix of covariates corresponding to EW

Nj=LLS.Nj;                  % number of model parameters	
Nk=LLS.Nk;                  % number of splines in value function
para0_u=para0(1:Nj);		% model parameters (utility function)
para0_W=para0(Nj+1:end);	% spline parameters in value function
delta=LLS.delta;
Nobs=LLS.Nobs;
sumwt=sum(LLS.wt);
assert(size(para0,1)==Nj+Nk&&size(para0,2)==1, ...
    'Error: para vector incorrect size');
assert(size(para_W,1)==size(para0_W,1), ...
    'Error: para_W vector incorrect size');
maxm=max(LLS.m);

assert(ismatrix(LLS.u_x) && size(LLS.u_x,2)==Nj, ...
    '# of variables in u does not match # of coefficients');
assert(ismatrix(LLS.EW_x) && size(LLS.EW_x,2)==Nk, ...
    '# of variables in EW does not match # of coefficients');
assert(ismatrix(LLS.W_x) && size(LLS.W_x,2)==Nk, ...
    '# of variables in W does not match # of coefficients');
assert(size(unique(LLS.id),1)==Nobs, ...
    '# of unique IDs does not match stated Nobs');

expv = exp(LLS.u_x*para0_u + delta*LLS.EW_x*para_W);
sumexpv=zeros(Nobs,1);
for m=1:maxm
    ids=LLS.id(LLS.m==m);
    sumexpv(ids)=expv(LLS.m==m,:)+sumexpv(ids);
end
f = LLS.W_x*para_W - log(sumexpv);
obj = sum(f.^2.*LLS.wt)/sumwt;
if LLS.eoscon,
    f2 = LLS.W_x(LLS.eos,:)*(para_W-para0_W);
    sumeoswt=sum(LLS.wt(LLS.eos));
    obj = obj + sum(f2.^2.*LLS.wt(LLS.eos))/sumeoswt;
end;

pr=expv./sumexpv(LLS.id); 
dWkdt = (repmat(delta*pr,1,Nk).*LLS.EW_x);
dWdt=zeros(Nobs,Nk);
for m=1:maxm
    ids=LLS.id(LLS.m==m);
    dWdt(ids,:)=dWkdt(LLS.m==m,:)+dWdt(ids,:);
end
dfdt=LLS.W_x - dWdt;
g=2*dfdt' * (LLS.wt.*f) /sumwt;
if LLS.eoscon,
    g2 = 2*repmat(f2,1,Nk).*LLS.W_x(LLS.eos,:);
    g = g + sum(g2.*repmat(LLS.wt(LLS.eos),1,Nk))' ...
        ./repmat(sumeoswt,Nk,1);
end;
