/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Estimate ordinal logit models of arrival counts
NOTES: 
******************************************************************************************/

global interval=5
global shiftlens 7 8 9 10 12
global regline hh? c.to? cen? c.to?#c.cen? miss_cen visits1h c.visits1h#c.to? ///
	i.miss_cen#c.to? i.nroom
global regline_bk1 hh? c.to? cen? c.to?#c.cen? miss_cen i.nroom
global arrival_estimates "${Estimates}/ologit"

*** Program ******************************************************************************
capture program drop estimate_arrival_model
program estimate_arrival_model
syntax if, [estfile(string)]
qui {
	preserve
	keep `if'
	if "`estfile'"!="" local splineline save estfile(`estfile')
	if "`estfile'"!="" ///
		make_spline, prefix(to) var(irelto_base) nknots(4) clearall `splineline'
	else make_spline, prefix(to) var(irelto_base) nknots(4)
	local time=1
	local run=1
	local regline_touse ${regline}
	while `run' {
		noi disp as text _n "Sample: `if'"  
		if regexm("`regline_touse'","cen") ///
			make_spline if census>0, prefix(cen) var(census) nknots(3) `splineline'
		if regexm("`regline_touse'","ym") ///
			make_spline, prefix(ym) var(ed_ym) nknots(5) `splineline'
		foreach var in shiftend_hh ed_hh {
			if regexm("`regline_touse'","`var'") {
				by `var', sort: egen count=count(_n)
				count
				replace count=count/r(N)
				replace `var'=24 if count<.04
				drop count
			}
		}
		if (regexm("`regline_touse'","i.ed_hh")|regexm("`regline_touse'","hh?")) {
			sort shiftend_hh
			if shiftend_hh[1]==shiftend_hh[_N] {
				local regline_touse `=regexr("`regline_touse'","i.ed_hh","")'
				local regline_touse `=regexr("`regline_touse'","hh\?","")'
			}
			else if regexm("`regline_touse'","hh") ///
				make_spline, prefix(hh) var(ed_hh) nknots(5) `splineline'			
		}
		
		noi ologit visits `regline_touse', iterate(20)
		if "`estfile'"!=""&e(converged) {
			noi estimates describe
			noi disp as text _n "  Saving as `estfile'"
			estimates save "`estfile'", replace
			local run=0
		}
		else if "${regline_bk`=`time''}"!="" {
			noi disp as text _n "Trying again with backup regline" 
			local regline_touse ${regline_bk`time'}
			local time=`time'+1
			local run=1
		}
		else local run=0
	}
	restore
}
end

*** Estimate model ***********************************************************************
use "${Data}/arrival_count_data", clear
set more off
qui foreach shiftlen in $shiftlens {
	levelsof nshifttype if shiftlen==`shiftlen'
	foreach nshifttype in `r(levels)' {
		local estfile ${arrival_estimates}_len`shiftlen'_`nshifttype'
		noi estimate_arrival_model ///
			if shiftlen==`shiftlen'&nshifttype==`nshifttype', ///
			estfile(`estfile')
	}
}
