/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Estimate dynamic programming model for shifts of different length
NOTES: 
- make_table_a-5.1.do redoes this for shifts 9 hours in length under different 
  specifications
*****************************************************************************************/

*** Initialize ***************************************************************************
global varver a
global shiftlens 7 8 9 10 12
global interval=5
global delta=.98
global estfile ${Data}/estimates_dp
global keepirelto_range 1 60 
global diff_lntdc_knots -1.5 -.1 .5
global diff_lntdc_vals -1.5 -1 -.5 0 .5
global callmatlab /Applications/MATLAB_R2016a.app/bin/matlab
	// Update to reflect MATLAB application on your computer

foreach shiftlen of $shiftlens {
global shiftlen=`shiftlen'
*** Prepare data, then export ************************************************************
prep_dp_data, if(shiftlen==${shiftlen}) ///
	discharge_estimates(clogit_len${shiftlen}) ///
	template(${Data}/sim_int5_d_template) nshifttypes(${nshifttypes_${shiftlen}}) ///
	arrival_estimates(ologit_len${shiftlen}) ///
	xbd_estimates(xbd_lntdc_len${shiftlen}) ///
	var_nknots(${var_nknots}) incensus keepirelto_range(${keepirelto_range})

// Model specification	
proc_BP_varlist, prep(eos(W_incensus_sp1) w(W_incensus_sp1 ///
	W_diff_lntdc_sp1 W_eos*) ///
	w1(W_incensus_sp1) w2(W_adjirelto_sp1) ///
	u(u_diff_lntdc_sp? u_xbd_lntdc_sp1)) estname(${varver})
	
local en ${varver}_
global vars ${`en'u_vars} ${`en'w_vars} ${`en'Ew_vars} ${`en'h_vars} ${`en'Eh_vars}
sort groupid sb
by groupid: gen choicenum=_n
keep groupid sb wt choice choicenum ${vars}
order groupid sb wt choice choicenum ${vars}
global infile dp_data_for_est.csv
outsheet using "${Data}/${infile}", comma replace

*** Process in MATLAB ********************************************************************
global estname dp_estimates_l${shiftlen}_${varver}
global outfile dp_para_${varver}.txt
global lcoutfile lcresults_${varver}.txt

local cmd cd Code;
local cmd `cmd' dp_main_fun('${infile}','${outfile}','lncom','lcmat.txt',
local cmd `cmd' 'lcoutfile','${lcoutfile}',
local cmd `cmd' 'delta',${delta},'fvalfile','fvalfile_${varver}.txt')
!"${callmatlab}" -nodisplay -nosplash -nodesktop -r "`cmd'; exit;" 

capture confirm file "${Output}/${outfile}"
while _rc {
	sleep 1000
	capture confirm file "${Output}/${outfile}"
}

*** Save results in Stata .dta file ******************************************************
ext_estimates, estname(${estname}) estfile(${estfile}) ///
	useresults(delta(${delta}) varver(${varver}) ///
	file(${Output}/${outfile})) append replace
}
