/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Estimate predicted length of stay in 5-minute intervals
NOTES: 
******************************************************************************************/

global interval=5
global shiftlens 7 8 9 10 12
global xbd_estimates "${Estimates}/xbd_lntdc"

*** Load base data ***********************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit room
gen_reltimeext, by(npid pod) posthrs(6) keepmaster 
discretize_dta, interval(${interval}) trim
gen byte sample=periods<=12*60/${interval}&periods>0&irelto_base<=12*60/${interval}& ///
	irelto_base!=.&shiftlen!=.
qui areg lntdc i.visit_dow i.nvisit_ym age age2 male female35 de? v? v?? p? ///
	dr? dl? triage_ed if sample, absorb(npid)
	predict d_lntdc, d
	predict xbd_lntdc, xbd	
gen ed_dow=dow(dofc(ed_tc))
gen ed_ym=(year(dofc(ed_tc))-2005)*12+month(dofc(ed_tc))-1
keep sb ed_t npid pod nroom nshifttype ed_hh ed_dow ed_ym irelfrom_base irelto_base ///
	postovl shiftlen preovl sample xbd_lntdc d_lntdc ed_tc dcord_t nshiftid
tempfile master
save `master', replace

gen_reltimeext, by(npid pod) posthrs(6) keepsched keepmaster interval(5) at(ed)
keep sb ed_t dcord_t npid nshiftid
gen_census_dense, interval(5) matchlag(1)
keep ed_t npid nshiftid census
duplicates drop
merge 1:m npid nshiftid ed_t using `master', keep(match) nogen
	
*** Estimate model ***********************************************************************
qui foreach shiftlen in $shiftlens {
	noi disp as text "Estimating for shiftlen==`shiftlen'"	
	preserve
	keep if sample
	by irelto_base, sort: egen count=count(_n)
	keep if shiftlen==`shiftlen'
	local est_file ${xbd_estimates}_len`shiftlen'
	make_spline, prefix(to) var(irelto_base) nknots(4) save clearall ///
		estfile(`est_file')
	make_spline, prefix(cen) var(census) nknots(3) save estfile(`est_file')
	make_spline, prefix(hh) var(ed_hh) nknots(5) save estfile(`est_file')
	make_spline, prefix(ym) var(ed_ym) nknots(5) save estfile(`est_file')
	reg xbd_lntdc hh? i.ed_dow ym? i.nroom c.to? d_lntdc [aw=1/count]
		// Note weighting to give each irelto_base equal weighting (i.e., weight 
		// observations near EOS higher)
	estimates save `est_file', replace
	restore
}

