/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figures 10 and 11
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

scalar lntotcost_base=6.749845
scalar shifts=22499 // Number of unique shiftid's in stored_dp_data.dta
scalar hours1=22950
scalar hours2=22950
scalar hours3=22952
scalar hours4=22952
scalar hours5=22952
scalar hours6=22952
scalar hours7=207752

*** Program ******************************************************************************
capture program drop load_data
program load_data
syntax, file(string) [if(string) by(string)]
qui {
	use "${Data}/`file'", clear
	foreach num of numlist 1/7 {
		capture rename const_b`num'_supp const_b_supp`num'
		capture rename b`num'_supp b_supp`num'
	}
	if "`file'"!="cf_sims_data" foreach var of varlist const_b? {
		if `""`if'""'!="" keep if `if'|cf_extend==0
		sum `var' if cf_extend==0
		replace `var'=r(mean) if cf_extend==0
	}
	else if `""`if'""'!="" keep if `if'
	foreach varname in b? const_b? count? t_ed_dcord_? diff_lntdc_? lntdc_ptadj_? ///
		avgcensus_? tr_eos_dc? b_supp? const_b_supp? {
		capture d `varname' 
		if _rc==0 {
			foreach var of varlist `varname' {
				rename `var' temp
				by cf_extend `by', sort: egen `var'=mean(temp)
				drop temp
			}
			local keeplist `keeplist' `varname'
		}
	}
	keep `keeplist' cf_extend `by'
	duplicates drop
	// Assume that physician goes home between the second-to-last and third-to-last 
	// discharge	
	gen eos_leave=(tr_eos_dc2+tr_eos_dc3)/2
}
end

capture program drop est_costs 
program est_costs
syntax , wage(real) [cap_scalar use_scalar use(string) restrict]
// restrict option requires irelto<=round(abs(cf_extend)) for there to be non-zero costs
if "`cap_scalar_b'"=="cap_scalar"&"`use_scalar'"=="use_scalar'" {
	disp as error "Error: Cannot use -use_scalar- and -cap_scalar- at same time"
	exit
}
if "`use'"=="" local use b
if !regexm("b lntdc_ptadj_ diff_lntdc_ const_b const_b_supp b_supp","`use'") ///
	|wordcount("`use'")!=1 {
	disp as error "Error: invalid -use-"
	exit
}
qui {
	by cf_extend, sort: assert _N==1
	if "`use_scalar'"=="" {
		egen `use'2_0=min(cond(cf_extend==0,`use'2,.))
		egen `use'1_0=min(cond(cf_extend==0,`use'1,.))
		gen scale=.208392/(`use'2_0-`use'1_0)
	}
	if "`cap_scalar'"=="cap_scalar" {
		foreach var in scale `use'1_0 `use'2_0 {
			sum `var'
			scalar `var'=r(mean)
			drop `var'
		}
	}
	foreach num of numlist 1/7 {
		sum t_ed_dcord_`num' if cf_extend==0
		scalar t_ed_dcord_`num'_0=r(mean)
	}
	foreach var in b const_b count t_ed_dcord_ diff_lntdc_ lntdc_ptadj_ avgcensus_ ///
		b_supp const_b_supp {
		capture d `var'?
		if _rc==0 local reshapelist `reshapelist' `var'
	}
	reshape long `reshapelist', i(cf_extend) j(irelto)

	// Physician-labor costs
	noi disp as text "Estimating physician-labor costs"
	// Evaluate when peer should arrive; assume to arrive when there are about 2 unseen
	// patients; consistent with data, which occurs on average a little after 2 hours before EOS
	gen rate=.
	foreach num of numlist 1/7 {
		replace rate=count/scalar(hours`num') if irelto==`num'
	}
	sum rate
	scalar maxrate=r(max)
	by cf_extend, sort: egen totpts=total(count)
	gen gap=cond(irelto>5,0,scalar(maxrate)-rate)
	gsort cf_extend -irelto
	by cf_extend: gen cumgap=sum(gap)
	by cf_extend: gen pre=2-cumgap if cumgap<2&cumgap[_n+1]>2
	by cf_extend: gen post=cumgap-2 if pre[_n-1]!=.
	by cf_extend: egen pre_=min(pre)
	by cf_extend: egen post_=min(post)
	by cf_extend: egen pre_irelto=min(pre*(irelto-2))
	by cf_extend: egen post_irelto=min(post*irelto)
	replace post_=scalar(maxrate) if post_==.
	replace post_irelto=0 if post_irelto==.
	gen peer_arrive=(pre_irelto+post_irelto)/(pre_+post_)
	gen lostwage=(eos_leave+peer_arrive)*`wage'
	
	// Patient-care costs
	noi disp as text "Estimating patient-care costs"
	if "`restrict'"=="" gen costpp=exp(lntotcost_base+scale* ///
		cond(`use'<`use'2_0,`use'2_0-`use',0))
	else gen costpp=exp(lntotcost_base+scale* ///
		cond(`use'<`use'2_0&irelto<=round(abs(cf_extend)),`use'2_0-`use',0))
	gen cost=(costpp-exp(lntotcost_base))*count/shifts
	replace totpts=totpts/shifts
	by cf_extend, sort: egen totptcost=total(cost)
	
	// Patient-time costs
	noi disp as text "Estimating patient-time costs"
	gen pttime=(t_ed_dcord_-scalar(t_ed_dcord_7_0))*20*count/shifts
	by cf_extend, sort: egen totpttime=total(pttime)

	// Summarize costs
	keep cf_extend totptcost lostwage eos_leave totpts totpttime 
	duplicates drop
	sort cf_extend
	gen totloss=totptcost+lostwage+totpttime
	foreach var in loss ptcost pts {
		egen tot`var'_0=min(cond(cf_extend==0,tot`var',.))
		gen net`var'=tot`var'-tot`var'_0
		drop *_0
	}
	format tot* net* %9.0gc
}
end

*** Second best **************************************************************************
load_data, if(scale_adjirelto==1&!use_cf_estname&cf_extend<=4.5& ///
	cfonly&keepirelto_range=="1 0") file(cf_sims_data)
est_costs, wage(120) use(const_b_supp)
tempfile orig
keep cf_extend netloss netpts
rename netloss netloss1
rename netpts netpts1
save `orig', replace

load_data, if(scale_adjirelto==1&!use_cf_estname&cf_extend<=4.5& ///
	cfonly&keepirelto_range=="1 0") file(cf_sims_data)
est_costs, wage(600) use(const_b_supp)
keep cf_extend netloss netpts
rename netloss netloss2
rename netpts netpts2
merge 1:1 cf_extend using `orig', nogen
save `orig', replace

load_data, if(scale_adjirelto==1&(use_cf_estname|cf_extend==0)&cf_extend<=4.5& ///
	!cfonly&keepirelto_range=="1 60") file(cf_sims_data)
est_costs, wage(120) use(const_b) restrict
keep cf_extend netloss netpts
rename netloss netloss3
rename netpts netpts3
sum netloss3 if cf_extend==3.5
local num1=r(mean)
sum netloss3 if cf_extend==4.5
local num2=r(mean)
sum netpts3 if cf_extend==3.5
local den1=r(mean)
sum netpts3 if cf_extend==4.5
local den2=r(mean)
replace netloss3=.3*`num1'+.7*`num2' if cf_extend==4
merge 1:1 cf_extend using `orig', nogen
save `orig', replace

load_data, if(scale_adjirelto==1&!use_cf_estname&cf_extend<=4.5& ///
	!cfonly&keepirelto_range=="1 60") file(cf_sims_data)
est_costs, wage(120) use(const_b) restrict
keep cf_extend netloss netpts
rename netloss netloss4
rename netpts netpts4
merge 1:1 cf_extend using `orig', nogen

keep if abs(cf_extend)>=1.5|cf_extend==0
	
sort netpts1
drop if cf_extend==0
// Recenter
scalar readj=netloss3[9]-netpts3[9]/(netpts3[10]-netpts3[9])*(netloss3[10]-netloss3[9])
gen netloss3_readj=netloss3-scalar(readj)
twoway (connected netloss3_readj netpts3, mcolor(black) lcolor(black) lpattern(dash) ///
	msymbol(Oh)), xtitle("Change in total patients assigned") ///
	ytitle("Change in total cost (dollars)") ///
	graphregion(color(white)) ylabel(, nogrid) 
graph export "${Output}/Figure_10.eps", as(eps) replace		

*** Revealed value of leisure ************************************************************	
load_data, if(scale_adjirelto==1&!use_cf_estname&cf_extend<=4.5& ///
	!cfonly&keepirelto_range=="1 0") file(cf_sims_data)
est_costs, wage(120) use(const_b_supp) cap_scalar
tempfile orig scalemod
gen byte distort=1
save `orig', replace

// Find new lntdc_ptadj coefficients for patient-care costs using scale_adjirelto==.1
load_data, if(round(scale_adjirelto*10)==1&!use_cf_estname&cf_extend<=4.5& ///
	!cfonly&keepirelto_range=="1 0") file(cf_sims_data)
// est_costs, wage(120) use(const_b_supp) use_scalar
drop count? 
save `scalemod', replace

// Use original counts (although these don't differ by much)
load_data, if(scale_adjirelto==1&!use_cf_estname&cf_extend<=4.5& ///
	!cfonly&keepirelto_range=="1 0") file(cf_sims_data)
keep count? cf_extend
merge 1:1 cf_extend using `scalemod', nogen
est_costs, wage(120) use(const_b_supp) use_scalar
gen byte distort=0

// Append to distorted (original) eos_leave and patient-care costs, 
// impute value of leisure
append using `orig'
keep cf_extend eos_leave totptcost distort
reshape wide eos_leave totptcost, i(cf_extend) j(distort)
sum eos_leave1 if cf_extend==0
gen net_eos_leave=eos_leave1-r(mean)
gen ratio=(totptcost1-totptcost0)/(eos_leave0-eos_leave1)
sort net_eos_leave
replace net_eos_leave=60*net_eos_leave
twoway (connected ratio net_eos_leave, mcolor(black) lcolor(black)), ///
	xtitle("Relative time of work completion (minutes)") ///
	ytitle("Revealed value of hour leisure (dollars)") xlabel(-60(20)60) ///
	graphregion(color(white)) ylabel(, nogrid) yline(120, lcolor(gs9))
graph export "${Output}/Figure_11.eps", as(eps) replace	
