/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 2
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

// Ending time and shift length
schedule_in_intervals
gen shiftend_hh=hh(shiftend_tc)
duplicates drop shiftid, force
by shiftend_hh shiftlen, sort: egen count=count(_n)
duplicates drop shiftend_hh shiftlen count, force
twoway scatter shiftlen shiftend_hh [aweight=count], msymbol(oh) mcolor(black) ///
	xlabel(0 "00:00" 6 "06:00" 12 "12:00" 18 "18:00" 23 "23:00") ///
	xtitle("Shift ending time") ytitle("Shift length (hours)") name(end_len, replace) ///
	title("A: Shift Length", color(black)) graphregion(color(white)) ylabel(, nogrid)

// Ending time and hours overlap
schedule_in_intervals
gen shiftend_hh=hh(shiftend_tc)
duplicates drop shiftid, force
by shiftend_hh postovl, sort: egen count=count(_n)
duplicates drop shiftend_hh postovl count, force
twoway scatter postovl shiftend_hh [aweight=count], msymbol(oh) mcolor(black) ///
	xlabel(0 "00:00" 6 "06:00" 12 "12:00" 18 "18:00" 23 "23:00") ///
	xtitle("Shift ending time") ytitle("Overlap (hours)") name(end_ovl, replace) ///
	title("B: Shift Overlap", color(black)) graphregion(color(white)) ylabel(, nogrid)

graph combine end_len end_ovl, ysize(6) xsize(4) cols(1) iscale(*1.1) ///
	graphregion(color(white))
graph export "${Output}/Figure_2.eps", as(eps) replace	
