/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 3
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

gen_working_data
gen_var, visittime
gen_reltimeext, by(npid) posthrs(4) keepsched interval(30) at(ed)

rename pod pod_adm
name_pods, shift(word(shiftid,1)) time(date(word(shiftid,2),"MDY"))
by ed_t npid, sort: egen visits_npid=count(sb)
by ed_t pod, sort: egen visits_pod=count(sb)
by ed_t, sort: egen visits_all=count(sb)
keep if nshifttype!=.

gen shiftend_t=minutes(shiftend_tc-clock("1jun2005 00:00","DMYhm"))/30
gen relto_t=shiftend_t-ed_t
keep ed_t npid pod nshifttype relto_t visits*
duplicates drop
decode nshifttype, gen(shifttype)
gen byte povl=cond(shifttype=="9_1_0",0, ///
	cond(shifttype=="9_1_1",1, ///
	cond(shifttype=="9_1_4",4, ///
	cond(shifttype=="9_4_6",6, ///
	cond(inlist(shifttype,"9_4_3","9_3_3"),3, ///
	cond(inlist(shifttype,"9_0_2","10_0_2"),2,.))))))

tempfile coefs master
save `master', replace
qui foreach postovl of numlist 0 1 4 6 3 2 {
	noi disp as result `postovl' " " _c 
	foreach type in pod npid {
		use `master', clear
		reg visits_`type' ibn.relto_t if povl==`postovl', nocon
		regsave
		keep var coef
		replace var=regexr(var,"\.relto_t","")
		destring var, force replace
		keep if var>=1&var<=18
		gen byte postovl=`postovl'
		rename var relto_t
		gen by="`type'"
		capture append using `coefs'
		save `coefs', replace
	}
}
gen crelto=-abs(relto_t/2)
gen coef_norm=2*coef

foreach postovl in 0 1 2 3 4 6 {
	if `postovl'<=1 local title `postovl' Hour Overlap
	else local title `postovl' Hours Overlap
	local cond if postovl==`postovl'
	if `postovl'>0 local tlineopt tline(-`postovl', lcolor(gs9))	
	twoway (connected coef_norm crelto `cond'&by=="npid", mcolor(black) lcolor(black) ///
		msymbol(O)) (connected coef_norm crelto `cond'&by=="pod", ///
		mcolor(black) lpattern(dash) lcolor(black) msymbol(Oh)) , ///
		ytitle("Visits per hour") xtitle("Hours relative to EOS") legend(off) ///
		name(visits_`postovl', replace) xlabel(-9(3)0) ylabel(0(1)5) aspectratio(.8) ///
		title(`title', color(black)) `tlineopt' graphregion(color(white)) ylabel(, nogrid)
}
	
graph combine visits_0 visits_1 visits_2 visits_3 visits_4 visits_6, ///
	ysize(7) rows(3) cols(2) ycommon iscale(*.9) graphregion(color(white))
graph export "${Output}/Figure_3.eps", as(eps) replace	
