/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 4
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

*** Load data ****************************************************************************
gen_working_data
gen_var, visittime control dem_vit outcomes
gen_reltimeext, by(pod npid) posthrs(4)
keep if nshifttype!=.
gen shiftend_t=minutes(shiftend_tc-clock("1jun2005 00:00","DMYhm"))/30
gen relto_t=ceil(minutes(shiftend_tc-ed_tc)/30)

*** Generate summary statistics **********************************************************
keep if relto_t<=16
sort relto_t
foreach var of varlist age esi dr3 dr1 dl1 dl2 {
	qui reg `var' i.visit_dow i.nvisit_ym i.ed_hh
	predict `var'_resid, resid
}
foreach var of varlist age* esi* dr3* dr1* dl1* dl2* {
	by relto_t: egen mean_`var'=mean(`var')
	by relto_t: egen condmean_`var'_0=mean(`var') if postovl==0
	by relto_t: egen mean_`var'_0=min(condmean_`var'_0)
	by relto_t: egen condmean_`var'_1=mean(`var') if postovl!=0
	by relto_t: egen mean_`var'_1=min(condmean_`var'_1)
}


mkspline ages=age, nknots(4) cubic
qui reg lntdc ages? male de? dl? dr?
predict xb_lntdc, xb
foreach var of varlist xb_lntdc age {
	foreach num of numlist 5 25 50 75 95 {
		by relto_t: egen pct`num'`var'=pctile(`var'), p(`num')
	}
}

gen temp=.
foreach num of numlist 1/4 {
	replace temp=cond(esi<=`num',1,0)
	by relto_t: egen propesi`num'=mean(temp)
}

keep pct* mean_* relto_t prop*
replace relto_t=-relto_t/2
duplicates drop

*** Plot graphs **************************************************************************
twoway (line mean_age relto_t, lcolor(black) lpattern(solid)) ///
	(line pct25age relto_t, lpattern(dash) lcolor(black)) ///
	(line pct75age relto_t, lpattern(dash) lcolor(black)) if relto_t<=8, ///
	xtitle("Hours relative to EOS") ytitle("Age") xlabel(-8(2)0) ylabel(20(10)60) ///
	title("A: Age", color(black) size(medlarge))  xscale(range(-8.5 0)) ///
	legend(off) aspectratio(1) ///
	graphregion(color(white)) ylabel(, nogrid) name(age, replace)
twoway (line propesi1 relto_t, lcolor(black) lpattern(shortdash)) ///
	(line propesi2 relto_t, lpattern(dash) lcolor(black)) ///
	(line propesi3 relto_t, lpattern(longdash) lcolor(black)) ///
	(line propesi4 relto_t, lpattern(solid) lcolor(black)) if relto_t<=8, ///
	xtitle("Hours relative to EOS") title("B: ESI", color(black) size(medlarge)) ///
	ytitle("Proportion") xlabel(-8(2)0) xscale(range(-8.5 0)) ///
	legend(off) graphregion(color(white)) ylabel(, nogrid) aspectratio(1) ///
	name(esi, replace) 
twoway (line mean_dr3 relto_t, lcolor(black) lpattern(solid)) ///
	(line mean_dr1 relto_t, lpattern(dash) lcolor(black)) if relto_t<=8, ///
	xtitle("Hours relative to EOS") ytitle("Proportion") xlabel(-8(2)0) ///
	ylabel(0(.2)1) xscale(range(-8.5 0)) legend(off) ///
	graphregion(color(white)) ylabel(, nogrid) ///
	title("C: Race", color(black) size(medlarge)) name(race, replace) aspectratio(1)
twoway (line mean_dl1 relto_t, lcolor(black) lpattern(solid)) ///
	(line mean_dl2 relto_t, lpattern(dash) lcolor(black)) if relto_t<=8, ///
	xtitle("Hours relative to EOS") ytitle("Proportion") xlabel(-8(2)0) ///
	ylabel(0(.2)1) xscale(range(-8.5 0)) legend(off) ///
	graphregion(color(white)) ylabel(, nogrid) aspectratio(1) ///
	title("D: Language", color(black) size(medlarge)) name(language, replace)
graph combine age esi race language, ysize(6) iscale(*.9) graphregion(color(white))
graph export "${Output}/Figure_4.eps", as(eps) replace	
