/*****************************************************************************************
AUTHOR: David Chan
DATE CREATED: December 3, 2017
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

*** Load data ****************************************************************************
gen_working_data
gen_var, visittime control dem_vit outcomes
gen_reltimeext, by(pod npid) posthrs(4)
keep if nshifttype!=.
gen shiftend_t=minutes(shiftend_tc-clock("1jun2005 00:00","DMYhm"))/30
gen relto_t=ceil(minutes(shiftend_tc-ed_tc)/30)

*** Generate summary statistics **********************************************************
keep if relto_t<=16
sort relto_t
mkspline ages=age, nknots(4) cubic
qui reg lntdc ages? male de? dl? dr?
predict xb_lntdc, xb
foreach var of varlist xb_lntdc {
	foreach num of numlist 5 25 50 75 95 {
		by relto_t: egen pct`num'`var'=pctile(`var'), p(`num')
	}
}
keep pct* relto_t
replace relto_t=-relto_t/2
duplicates drop

*** Plot graph **************************************************************************
twoway (line pct5xb_lntdc relto_t, lcolor(black) lpattern(shortdash)) ///
	(line pct25xb_lntdc relto_t, lpattern(dash) lcolor(black)) ///
	(line pct50xb_lntdc relto_t, lpattern(solid) lcolor(black)) ///
	(line pct75xb_lntdc relto_t, lpattern(dash) lcolor(black)) ///
	(line pct95xb_lntdc relto_t, lpattern(shortdash) lcolor(black)) if relto_t<=8, ///
	xtitle("Hours relative to EOS") ytitle(Predicted log length of stay) ///
	xlabel(-8(2)0) xscale(range(-8.5 0)) ///
	legend(off) graphregion(color(white)) ylabel(, nogrid)
graph export "${Output}/Figure_5.eps", as(eps) replace	
