/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 6
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
- Results are identical to those in Tables 2 and 3, but are presented in graphical form
*****************************************************************************************/

global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed i.irelfrom 

*** Load data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers

*** Run regressions **********************************************************************
// Identical to Tables 2 (Column 5) and 3 
tempfile master estfile
save `master', replace
qui foreach outcome in lntdc admit lntotcost all_c_all {
	use `master', clear
	noi disp as text "`outcome'"
	areg `outcome' ib(last).irelto ${controlvar}, absorb(team)
	regsave
	keep var coef stderr
	rename coef coeff 
	rename stderr se
	keep if regexm(var,"[1-6]\.irelto")
	replace var=regexr(var,"\.irelto","")
	gen outcome="`outcome'"
	destring var, force gen(irelto)
	capture append using `estfile'
	save `estfile', replace
}

*** Plot graph **************************************************************************
gen lcl=coeff-1.96*se
gen ucl=coeff+1.96*se
replace irelto=-abs(irelto)
foreach outcome in lntdc admit lntotcost all_c_all {
	local ytitle_lntdc Log (hours) length of stay
	local ytitle_admit Admission probability
	local ytitle_lntotcost Log total direct costs
	local ytitle_all_c_all Number of orders
	local title_lntdc A: Length of Stay
	local title_all_c_all B: Orders
	local title_admit C: Inpatient Admission
	local title_lntotcost D: Costs
	twoway (rcap ucl lcl irelto, lcolor(black) lpattern(dash)) ///
		(scatter coeff irelto, mcolor(black) msymbol(O)) if outcome=="`outcome'", ///
		legend(off) aspectratio(1) xtitle("Hours relative to EOS") ///
		ytitle("`ytitle_`outcome''") title("`title_`outcome''", size(medlarge) color(black)) ///
		name(avg_`outcome', replace) graphregion(color(white)) ylabel(, nogrid)
}
graph combine avg_lntdc avg_all_c_all avg_admit avg_lntotcost, ysize(6) iscale(*.9) ///
	graphregion(color(white))
graph export "${Output}/Figure_6.eps", as(eps) replace	
