/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 7
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
*** Load data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen irelfrom_temp=ceil(cond(ed_tc>shiftbeg_tc,hours(ed_tc-shiftbeg_tc),.))
replace irelfrom_temp=13 if irelfrom_temp>13&irelfrom_temp!=.
mkspline from=irelfrom_temp, knots(1 3 5 7) cubic
gen ipostovl=.
replace ipostovl=0 if postovl==0
replace ipostovl=1 if postovl==1
replace ipostovl=4 if postovl>=2&postovl!=.
gen hasovl=cond(ipostovl<=1,0,cond(postovl!=.,1,.))

*** Run regressions **********************************************************************
global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed 

tempfile master estfile
save `master', replace
qui foreach var of varlist all_c_all lntotcost admit lntdc /*admit lntotcost all_c_all*/ {
	noi disp as text "`var'"
	use `master', clear
	areg `var' i.hasovl#ib(last).irelto ${controlvar} from?, absorb(team)
	test 0.hasovl#1.irelto=1.hasovl#1.irelto
	scalar p_`var'=r(p)
	
	areg `var' i.ipostovl#ib(last).irelto ${controlvar} from?, absorb(team)
	regsave
	keep var coef stderr
	rename coef coeff 
	rename stderr se
	drop if coeff==0&se==0
	keep if regexm(var,"[1-7]b?\.irelto")
	replace var=regexr(var,"b?\.irelto","")
	gen irelto=substr(var,-1,1)
	gen postovl=substr(var,1,1)
	destring irelto, force replace
	destring postovl, force replace
	drop var
	gen outcome="`var'"
	capture append using `estfile'
	save `estfile', replace	
}

*** Plot graph **************************************************************************
replace irelto=-abs(irelto)
sort outcome postovl irelto
by outcome postovl: gen lastcoeff=coeff[1]
replace coeff=coeff-lastcoeff if postovl>0
drop if irelto==-7
foreach outcome in lntdc admit lntotcost all_c_all {
	local ytitle_lntdc Log (hours) length of stay
	local ytitle_admit Admission probability
	local ytitle_lntotcost Log total direct costs
	local ytitle_all_c_all Number of orders
	local title_lntdc A: Length of Stay
	local title_all_c_all B: Orders
	local title_admit C: Inpatient Admission
	local title_lntotcost D: Costs
	twoway (connected coeff irelto if outcome=="`outcome'"&postovl==0, mcolor(black) ///
			msymbol(Oh) lpattern(dash) lcolor(black)) ///
		(connected coeff irelto if outcome=="`outcome'"&postovl==1, mcolor(black) ///
			msymbol(Th) lpattern(dash) lcolor(black)) ///
		(connected coeff irelto if outcome=="`outcome'"&postovl==4, mcolor(black) ///
			msymbol(O) lcolor(black)), ///
		legend(off) aspectratio(1) xtitle("Hours relative to EOS") ///
		ytitle("`ytitle_`outcome''") title("`title_`outcome''", size(medlarge) color(black)) ///
		name(`outcome', replace) graphregion(color(white)) ylabel(, nogrid) ///
		note("{it:p} = `=string(scalar(p_`outcome'),"%9.4f")'", position(5) ring(0))
}		

graph combine lntdc all_c_all admit lntotcost, ysize(6) iscale(*.9) graphregion(color(white))
graph export "${Output}/Figure_7.eps", as(eps) replace	
