/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 8
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

discretize_dta, interval(15) trim
gen_census, of(npid) at_from(ed) at_to(dcord) match interval(15) gens(avg)
gen lntdc_ptadj=ln(t_ed_dcord/avgcensus)
gen irelto_orig=ceil(hours(shiftend_tc-ed_tc))
gen irelto=cond(irelto_orig!=.,min(irelto_orig,7),.)
gen irelfrom=ceil(cond(ed_tc>shiftbeg_tc,hours(ed_tc-shiftbeg_tc),.))
replace irelfrom=13 if irelfrom>13&irelfrom!=.

mkspline from=irelfrom, knots(1 3 5 7) cubic

foreach var in *eoscat* *Xcat* eos_ed_hh {
	capture drop `var'
}
gen eos_ed_hh=mod(ed_hh+irelto_orig,24)
gen eoscat=cond(eos_ed_hh>=6&eos_ed_hh<=20,1,2)
foreach num of numlist 1/3 {
	gen ireltoXcat`num'=irelto*(eoscat==`num')
	replace ireltoXcat`num'=7 if eoscat!=`num'
}

*** Run regression ***********************************************************************
global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed 
areg lntdc_ptadj i.eoscat#ib(last).irelto i.eoscat c.from? ${controlvar}, ///
	absorb(team)
estimates store reg

/*
Linear regression, absorbing indicators         Number of obs     =    334,783
                                                F( 182, 116836)   =     119.76
                                                Prob > F          =     0.0000
                                                R-squared         =     0.8094
                                                Adj R-squared     =     0.4538
                                                Root MSE          =     0.7430

--------------------------------------------------------------------------------
   lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
 eoscat#irelto |
          1 1  |  -.3022931    .068847    -4.39   0.000    -.4372321   -.1673541
          1 2  |     .00991   .0329169     0.30   0.763    -.0546067    .0744267
          1 3  |   .1029784   .0271641     3.79   0.000     .0497373    .1562196
          1 4  |   .0515282   .0231776     2.22   0.026     .0061004     .096956
          1 5  |   .0528099   .0199129     2.65   0.008     .0137809    .0918389
          1 6  |   .0420435    .015574     2.70   0.007     .0115188    .0725683
          2 1  |  -.0206488   .0726901    -0.28   0.776    -.1631202    .1218226
          2 2  |   .0244015   .0353554     0.69   0.490    -.0448944    .0936974
          2 3  |  -.0025294   .0280522    -0.09   0.928    -.0575113    .0524525
          2 4  |  -.0170921   .0227386    -0.75   0.452    -.0616594    .0274751
          2 5  |   .0159362   .0197166     0.81   0.419    -.0227081    .0545804
          2 6  |  -.0435441   .0156177    -2.79   0.005    -.0741545   -.0129337
		  
. test 1.eoscat#1.irelto=2.eoscat#1.irelto

 ( 1)  1b.eoscat#1.irelto - 2.eoscat#1.irelto = 0

       F(  1,116836) =    9.48
            Prob > F =    0.0021
			
. qui areg lntdc_ptadj ib(last).irelto i.eoscat 2.eoscat#ib(last).irelto c.from? ///
	${controlvar_short}, absorb(team)			
. test 2.eoscat#1.irelto 2.eoscat#2.irelto 2.eoscat#3.irelto 2.eoscat#4.irelto ///
	2.eoscat#5.irelto 2.eoscat#6.irelto
	
 ( 1)  2.eoscat#1.irelto = 0
 ( 2)  2.eoscat#2.irelto = 0
 ( 3)  2.eoscat#3.irelto = 0
 ( 4)  2.eoscat#4.irelto = 0
 ( 5)  2.eoscat#5.irelto = 0
 ( 6)  2.eoscat#6.irelto = 0

       F(  6,116836) =    8.11
            Prob > F =    0.0000
*/

estimates restore reg
regsave
keep var coef stderr
rename coef coeff 
rename stderr se
drop if coeff==0&se==0
keep if regexm(var,"[1-7]b?\.irelto")
replace var=regexr(var,"b?\.irelto","")
gen irelto=substr(var,-1,1)
gen eoscat=substr(var,1,1)
destring irelto, force replace
destring eoscat, force replace

*** Plot graph **************************************************************************
replace irelto=-abs(irelto)
twoway (connected coeff irelto if eoscat==1, mcolor(black) msymbol(O) ///
	lcolor(black)) (connected coeff irelto if eoscat==2, mcolor(black) msymbol(Oh) ///
	lpattern(dash) lcolor(black)), ytitle("Workload-adjusted log LOS") ///
	legend(off) xtitle("Hours relative to EOS") ///
	graphregion(color(white)) ylabel(, nogrid)
graph export "${Output}/Figure_8.eps", as(eps) replace	
