/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure 9
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global interval=5
global shiftlen=9
// Focus on shifts that are 9 hours in length (comprise 90% of data)
global var_nknots xbd_lntdc=3 diff_lntdc=3 adjirelto=3 census=3 irelto_base=4 ///
	visits1h=3 reldc_h=3
global nshifttypes_9 14/35
global keepirelto_range 1 60
// Focus on 5-minute intervals within last 5 hours prior to EOS

*** Generate data ***********************************************************************
// Uses data from prepare_stored_dp_data.do

prep_dp_data, if(shiftlen==${shiftlen}) ///
	discharge_estimates(clogit_len${shiftlen}) ///
	template(${Data}/sim_int5_d_template) nshifttypes(${nshifttypes_${shiftlen}}) ///
	arrival_estimates(ologit_len${shiftlen}) ///
	xbd_estimates(xbd_lntdc_len${shiftlen}) ///
	var_nknots(${var_nknots}) incensus keepirelto_range(${keepirelto_range})
/* Given large size of data, select random 10% of shifts
preserve
set seed 0
gen rand=runiform()
by nshiftid, sort: replace rand=rand[1]
keep if rand<.1
keep nshiftid 
save "${Data}/nshiftid_sample_xwalk.dta", replace
restore
*/
merge m:1 nshiftid using "${Data}/nshiftid_sample_xwalk.dta", ///
	keep(match) nogen
rename groupid oldgroupid
egen groupid=group(oldgroupid)
drop oldgroupid	
save "${Data}/temp_data_dp.dta", replace
	
use "${Data}/temp_data_dp.dta", clear
ext_estimates, estname(dp_estimates_l9_a) estfile(${Data}/estimates_dp) ///
	predict(xb_dp) nodisp
gen num=exp(xb_dp)
by groupid, sort: egen den=total(num)
gen pr_dp=num/den
drop if sb==0
gen relto=-irelto/12

*** Plot figure *************************************************************************
binned_scatter, ///
	yvar(choice pr pr_dp) xvar(relto) xlabel(Hours to EOS) ///
	ylabel(Pr(Discharge)) msymbol(O Oh Th) ///
	graphopts(legend(off) aspectratio(1) title("A: Time to EOS", color(black) ///
	size(medlarge)) name(relto, replace))
binned_scatter, ///
	yvar(choice pr pr_dp) xvar(W_incensus_sp1) xlabel(Census) ///
	ylabel(Pr(Discharge)) msymbol(O Oh Th) ///
	graphopts(legend(off) aspectratio(1) title("B: Census", color(black) ///
	size(medlarge)) name(incensus, replace))
binned_scatter, ///
	yvar(choice pr pr_dp) xvar(u_xbd_lntdc_sp1) xlabel(Predicted log LOS) ///
	ylabel(Pr(Discharge)) msymbol(O Oh Th) ///
	graphopts(legend(off) aspectratio(1) title("C: Predicted LOS", color(black) ///
	size(medlarge)) name(xbd_lntdc, replace))
binned_scatter, ///
	yvar(choice pr pr_dp) xvar(u_diff_lntdc_sp1) xlabel(Deviation log LOS) ///
	ylabel(Pr(Discharge)) msymbol(O Oh Th) ///
	graphopts(legend(off) aspectratio(1) title("D: Deviation LOS", color(black) ///
	size(medlarge)) name(diff_lntdc, replace))
graph combine relto incensus xbd_lntdc diff_lntdc, ysize(6) iscale(*.9) ///
	graphregion(color(white)) 
graph export "${Output}/Figure_9.eps", as(eps) replace	
