/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure A-2.1
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen irelto=ceil(hours(shiftend_tc-ed_tc))

*** Run regression ***********************************************************************
global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? v? v?? p? ///
	dr? dl? triage_ed
replace irelto=7 if irelto==8&shiftlen==8
qui reg lntdc ib(last).irelto ${controlvar} if (irelto<=shiftlen)&(shiftlen==8|shiftlen==7)

tempfile master results
save `master', replace
regsave
keep var coef stderr
rename coef coeff 
rename stderr se
drop if coeff==0&se==0
keep if regexm(var,"[1-9]b?\.irelto")
gen irelto=substr(var,1,1)
destring irelto, force replace
gen shiftlen="7|8"
save `results', replace

qui foreach num of numlist 9/10 {
	use `master', clear
	reg lntdc ib(last).irelto ${controlvar} if irelto<=`num'&shiftlen==`num'
	regsave
	keep var coef stderr
	rename coef coeff 
	rename stderr se
	drop if coeff==0&se==0
	keep if regexm(var,"[1-9]b?\.irelto")
	gen irelto=substr(var,1,1)
	destring irelto, force replace
	gen shiftlen="`num'"	
	capture append using `results'
	save `results', replace
}

*** Plot graph **************************************************************************
/*
irelto	coeff	se	shiftlen
1	-0.3964674	0.1584319	10
2	-0.2395818	0.052421	10
3	-0.0801955	0.0389075	10
4	-0.1040954	0.0374301	10
5	-0.0566812	0.0337765	10
6	-0.0233359	0.0340061	10
7	-0.0460103	0.030525	10
8	0.0324866	0.0333824	10
9	0.0268941	0.0363089	10
1	-0.5100288	0.0261396	9
2	-0.2427163	0.0118193	9
3	-0.0902991	0.0087243	9
4	-0.0665208	0.0071239	9
5	-0.0085988	0.0089036	9
6	-0.004461	0.0065939	9
7	-0.0057949	0.0079864	9
8	0.0132134	0.0087059	9
1	-0.5028331	0.1318096	7|8
2	-0.2325802	0.0443951	7|8
3	-0.0427914	0.0322481	7|8
4	-0.0373722	0.0305811	7|8
5	0.0010214	0.0287347	7|8
6	0.0042364	0.0264628	7|8
*/

replace irelto=-irelto
gen lcl=coeff-1.96*se if se>0
gen ucl=coeff+1.96*se if se>0
gen irelfrom=irelto+cond(shiftlen=="7|8",7.5,real(shiftlen))
twoway (connected coeff irelto if shiftlen=="9", mcolor(black) lcolor(black) msymbol(O)) ///
	(connected coeff irelto if shiftlen=="7|8", mcolor(black) lcolor(black) msymbol(Oh) lpattern(longdash)) /// 
	(connected coeff irelto if shiftlen=="10", mcolor(black) lcolor(black) msymbol(Th) lpattern(longdash)) ///
	, xtitle("Hours relative to EOS") ytitle("Log (hours) length of stay") legend(off) ///
	name(irelto, replace) title("A: EOS", color(black)) graphregion(color(white)) ylabel(, nogrid)
twoway (connected coeff irelfrom if shiftlen=="9", mcolor(black) lcolor(black) msymbol(O)) ///
	(connected coeff irelfrom if shiftlen=="7|8", mcolor(black) lcolor(black) msymbol(Oh) lpattern(longdash)) /// 
	(connected coeff irelfrom if shiftlen=="10", mcolor(black) lcolor(black) msymbol(Th) lpattern(longdash)) ///
	, xtitle("Hours relative to shift beginning") ytitle("Log (hours) length of stay") legend(off) ///
	name(irelfrom, replace) title("B: Shift Beginning", color(black)) graphregion(color(white)) ylabel(, nogrid)

graph combine irelto irelfrom, ysize(6) xsize(4) cols(1) iscale(*1.1) graphregion(color(white))
graph export "${Output}/Figure_A-2.1.eps", as(eps) replace	
