/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figure A-3.1
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

*** Analysis *****************************************************************************
global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? v? v?? p? ///
	dr? dl? triage_ed
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=9 if irelto>9&irelto!=. // I want to focus on 9-hour shifts now

// Generate time components as proportion of total length of stay
gen intord_prop=cond(last_all_real_signed_tc==.|first_all_signed_tc==.,., ///
	max(hours(min(last_all_real_signed_tc,dcord_tc)- ///
	max(first_all_signed_tc,ed_tc)),0))/t_ed_dcord
replace t_ed_ord=. if last_all_real_signed_tc==.
gen edtord_prop=cond(t_ed_ord==.,.,max(t_ed_ord,0))/t_ed_dcord
gen lordtdc_prop=cond(dcord_tc==.|last_all_real_signed_tc==.,., ///
	max(hours(dcord_tc-last_all_real_signed_tc),0))/t_ed_dcord
gen edtord_subprop=edtord_prop/(edtord_prop+lordtdc_prop)

// Linear predictions to simplify model
qui areg lntdc ${controlvar}, absorb(team)
predict xb_lntdc, xbd
gen lnintord=ln(hours(last_all_real_signed_tc-first_all_signed_tc))
qui areg lnintord ${controlvar}, absorb(team)
predict xb_lnintord, xbd

// Length of stay
qui areg lntdc ib(last).irelto ${controlvar} if shiftlen>=9, absorb(team)
/*
Linear regression, absorbing indicators           Number of obs   =     358651
                                                  F( 174, 128503) =     146.01
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.7856
                                                  Adj R-squared   =     0.4016
                                                  Root MSE        =     0.6665

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.7754642   .0400181   -19.38   0.000    -.8538989   -.6970295
          2  |  -.5440149    .012906   -42.15   0.000    -.5693105   -.5187193
          3  |  -.3445981   .0100638   -34.24   0.000    -.3643231   -.3248732
          4  |   -.260245   .0088195   -29.51   0.000    -.2775312   -.2429589
          5  |  -.2185153   .0087314   -25.03   0.000    -.2356287    -.201402
          6  |  -.1536974   .0078452   -19.59   0.000    -.1690739   -.1383208
          7  |  -.1785381   .0084101   -21.23   0.000    -.1950217   -.1620545
          8  |  -.1460838   .0086866   -16.82   0.000    -.1631094   -.1290582
*/
mat b_lntdc=e(b)
sum lntdc t_ed_dcord if irelto==9&shiftlen>=9, detail
// Median values: lntdc 1.22 log hours; t_ed_dcord 3.38 hours

qui fraclogit intord_prop ib(last).irelto xb_lntdc xb_lnintord if shiftlen>=9
margins irelto, post
mat b_intord_prop=e(b)
/*
fractional logit results                                       Obs  = 283468 
                                                               rmse = 1.58320
                                                               df   = 12     
                                                           pearson  = 4.5e+05
------------------------------------------------------------------------------
 intord_prop |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5272929   .0478577   -11.02   0.000    -.6210923   -.4334935
          2  |   .0228776   .0146991     1.56   0.120    -.0059321    .0516874
          3  |   .0371574   .0093234     3.99   0.000     .0188838     .055431
          4  |   .0272995   .0086843     3.14   0.002     .0102786    .0443205
          5  |   .0568865   .0082483     6.90   0.000     .0407202    .0730529
          6  |   .0504095   .0080649     6.25   0.000     .0346026    .0662163
          7  |   .0549324   .0079808     6.88   0.000     .0392903    .0705744
          8  |   .0428557   .0080549     5.32   0.000     .0270684    .0586431
          9  |          0  (empty)
...

Predictive margins                                Number of obs   =     283468

Expression   : Linear prediction, predict()

------------------------------------------------------------------------------
             |            Delta-method
             |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.4700503   .0476054    -9.87   0.000    -.5633553   -.3767454
          2  |   .0801202   .0138678     5.78   0.000     .0529398    .1073006
          3  |      .0944   .0079574    11.86   0.000     .0788037    .1099963
          4  |   .0845421   .0071994    11.74   0.000     .0704315    .0986528
          5  |   .1141291    .006669    17.11   0.000     .1010582       .1272
          6  |    .107652   .0064424    16.71   0.000     .0950251     .120279
          7  |    .112175   .0063377    17.70   0.000     .0997534    .1245966
          8  |   .1000983   .0064313    15.56   0.000     .0874932    .1127034
          9  |   .0572426   .0048495    11.80   0.000     .0477377    .0667474
------------------------------------------------------------------------------
*/

qui fraclogit edtord_subprop ib(last).irelto xb_lntdc xb_lnintord if shiftlen>=9
margins irelto, post
mat b_edtord_subprop=e(b)
/*
fractional logit results                                       Obs  = 280367 
                                                               rmse = 2.43464
                                                               df   = 12     
                                                           pearson  = 6.8e+05
------------------------------------------------------------------------------
edtord_sub~p |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -1.026379   .0620875   -16.53   0.000    -1.148069   -.9046901
          2  |  -.3853996   .0184585   -20.88   0.000    -.4215776   -.3492216
          3  |  -.1499879   .0116314   -12.90   0.000     -.172785   -.1271908
          4  |  -.1071597   .0108276    -9.90   0.000    -.1283815   -.0859379
          5  |  -.1101154    .010278   -10.71   0.000      -.13026   -.0899709
          6  |  -.1252348   .0100512   -12.46   0.000    -.1449347   -.1055349
          7  |  -.1578241   .0099407   -15.88   0.000    -.1773075   -.1383407
          8  |  -.1409513   .0100309   -14.05   0.000    -.1606115   -.1212912
          9  |          0  (empty)
...

Expression   : Linear prediction, predict()

------------------------------------------------------------------------------
             |            Delta-method
             |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.8363526   .0617874   -13.54   0.000    -.9574536   -.7152516
          2  |  -.1953728   .0174355   -11.21   0.000    -.2295458   -.1611998
          3  |   .0400389   .0099382     4.03   0.000     .0205604    .0595175
          4  |   .0828671   .0089858     9.22   0.000     .0652553    .1004789
          5  |   .0799114   .0083175     9.61   0.000     .0636094    .0962134
          6  |   .0647921   .0080375     8.06   0.000     .0490388    .0805453
          7  |   .0322027   .0078999     4.08   0.000     .0167192    .0476862
          8  |   .0490755   .0080135     6.12   0.000     .0333692    .0647817
          9  |   .1900268   .0060328    31.50   0.000     .1782028    .2018508
------------------------------------------------------------------------------
*/

*** Plot graph **************************************************************************
clear
set obs 9
gen irelto=_n
foreach var in lntdc intord_prop edtord_subprop {
	capture drop `var'
	gen `var'=.
	foreach num of numlist 1/9 {
		replace `var'=b_`var'[1,`num'] if _n==`num'
	}
}
/*
irelto	lntdc	intord_prop	edtord_subprop
1	-0.7754642	-0.4700503	-0.8363526
2	-0.5440149	0.0801202	-0.1953728
3	-0.3445981	0.0944	0.0400389
4	-0.260245	0.0845421	0.0828671
5	-0.2185153	0.1141291	0.0799114
6	-0.1536974	0.107652	0.0647921
7	-0.1785381	0.112175	0.0322027
8	-0.1460838	0.1000983	0.0490755
9	0	0.0572426	0.1900268
*/ 
// Median lntdc at irelto==9&shiftlen>=9 is 1.22 log hours
gen los=exp(lntdc+1.22)
foreach var of varlist intord_prop edtord_subprop {
	replace `var'=exp(`var')/(1+exp(`var'))
}
gen edtord_prop=(1-intord_prop)*edtord_subprop
gen lordtdc_prop=(1-intord_prop)*(1-edtord_subprop)
foreach var in intord edtord lordtdc {
	gen `var'=los*`var'_prop
}
gen lord=edtord+intord
gen lord_prop=edtord_prop+intord_prop
gen ed=0
replace irelto=-irelto

twoway (connected edtord irelto, msymbol(Oh) mcolor(black) lcolor(black) lpattern(dash)) ///
	(connected lord irelto, msymbol(Th) mcolor(black) lcolor(black) lpattern(dash)) ///
	(connected los irelto, msymbol(O) mcolor(black) lcolor(black)), ///	
	xtitle("Hours relative to EOS") ytitle("Cumulative duration in hours") legend(off) ///
	name(duration, replace) title("A: Duration", color(black)) ///
	graphregion(color(white)) ylabel(, nogrid)
	
twoway (connected edtord_prop irelto, msymbol(Oh) mcolor(black) lcolor(black) lpattern(dash)) ///
	(connected lord_prop irelto, msymbol(Th) mcolor(black) lcolor(black) lpattern(dash)), ///
	xtitle("Hours relative to EOS") ytitle("Cumulative proportion") legend(off) ylabel(0(.2)1) ///
	name(prop, replace) title("B: Proportion of Time", color(black)) ///
	graphregion(color(white)) ylabel(, nogrid)

graph combine duration prop, ysize(6) xsize(4) cols(1) iscale(*1.1) graphregion(color(white))
graph export "${Output}/Figure_A-3.1.eps", as(eps) replace	
