/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Figures A-7.1 and A-7.2
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
*** Figure A-7.1 *************************************************************************
gen_working_data, poe(all)
gen_reltimeext, by(pod npid) posthrs(4)

keep if nshifttype!=.
sort sb last_npid_signed_tc
keep sb first_npid_signed_tc last_npid_signed_tc aor npidpoe ///
	shiftend_tc nshifttype shiftid npid
foreach type in first last {
	gen `type'_npid_releos=hours(`type'_npid_signed_tc-shiftend_tc)
	drop `type'_npid_signed_tc
}
gen shiftend_hh=hh(shiftend_tc)
sort shiftid
local index=0
foreach num of numlist -6(.25)4 {
	disp as result "`num' " _c
	gen byte temp=(`num'<=last_npid_releos)&(`num'>=first_npid_releos)
	by shiftid: egen any_npid_`index'=max(temp*npidpoe>0)
	by shiftid: egen aor_`index'=max(temp*aor)
	drop temp
	local index=`index'+1
}
keep shiftid any_npid* aor_* shiftend_hh npid
duplicates drop
reshape long aor_ any_npid_, j(index) i(shiftid)
foreach var in any_npid aor {
	sort index npid
	if inlist("`var'","any_npid","aor") by index npid: egen npid_`var'=total(`var'_)
	by index: egen tot_`var'=total(`var'_)
	by index shiftend_hh, sort: egen hh_`var'=total(`var'_)
}

preserve
keep index tot_*
duplicates drop
gen releos_h=-6+index/4
gen aor_cond_sh=tot_aor/tot_any_npid
// Conditional on any attending still ordering

twoway line aor_cond_sh releos_h, ylabel(0(.2)1) ytitle("AOR order share") ///
	xtitle("Hours relative to EOS")	graphregion(color(white)) ylabel(, nogrid) ///
	xline(0, lcolor(black)) legend(off) lpattern(dash) lcolor(black)
graph export "${Output}/Figure_A-7.1.eps", as(eps) replace
restore

*** Figure A-7.2 *************************************************************************
keep index shiftend_hh hh_*
duplicates drop
gen releos_h=-6+index/4
keep if releos_h==1
gen aor_cond_sh=hh_aor/hh_any_npid
by shiftend_hh, sort: egen count=total(hh_any)
keep shiftend_hh aor_cond_sh count
tempfile aor_cond_sh
save `aor_cond_sh', replace	

// Add on average census
gen_working_data
gen_reltimeext, by(pod npid) posthrs(6) keepmaster 
gen byte sample=t_ed_dcord<=12&t_ed_dcord>0&ed_tc<shiftend_tc& ///
	ed_tc>shiftbeg_tc-msofhours(3)&shiftlen!=.
drop if dcord_tc==.|ed_tc==.|!sample
gen_census, of(npid) interval(15)
gen_reltimeext, by(npid) at(at) interval(30) keepsched
replace census=0 if census==.
by nshiftid, sort: egen totcensus=total(census)
drop if totcensus==0
drop totcensus
gen shiftend_t=minutes(shiftend_tc-clock("1jun2005 00:00","DMYhm"))/30
keep if shiftend_t==at_t
gen shiftend_hh=hh(shiftend_tc)
by shiftend_hh, sort: egen avgcensus=mean(census)
keep shiftend_hh avgcensus
duplicates drop
merge 1:1 shiftend_hh using `aor_cond_sh', keep(match)

local max_census=6
local max_aor_sh=1
twoway (scatteri `max_aor_sh' 6 `max_aor_sh' 20, bcolor(gs15) recast(area)) ///
	(scatter aor_cond_sh shiftend_hh, msymbol(Oh) mcolor(black)) ///
	, name(aor_sh, replace) title("A: AOR Order Share") ///
	ylabel(0(.2)1, nogrid) ///
	xlabel(0 "00:00" 6 "06:00" 12 "12:00" 18 "18:00" 23 "23:00") ///
	ytitle("Order share (1h post EOS)") xtitle("Shift ending time") ///
	graphregion(color(white)) legend(off)
twoway (scatteri `max_census' 6 `max_census' 20, bcolor(gs15) recast(area)) ///
	(scatter avgcensus shiftend_hh, msymbol(Oh) mcolor(black)) ///
	, name(avgcensus, replace) title("B: Census") ///
	ylabel(0(2)6, nogrid) ///
	xlabel(0 "00:00" 6 "06:00" 12 "12:00" 18 "18:00" 23 "23:00") ///
	ytitle("Census at EOS") xtitle("Shift ending time") ///
	graphregion(color(white)) legend(off)
graph combine aor_sh avgcensus, ysize(6) xsize(4) cols(1) iscale(*1.1) ///
	graphregion(color(white))
graph export "${Output}/Figure_A-7.2.eps", as(eps) replace
