/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table 1
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
global begtime clock("1jun2005 00:00","DMYhm")
global controlvar1 age age2 male female35 de? dr? dl?
global controlvar2 age age2 male female35 de? dr? dl? v? v??
global controlvar_comp i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom 
	
capture program drop residualize
program residualize
syntax varlist, using(string) [gen(string)]
qui {
	assert wordcount("`varlist'")==1
	local var `varlist'
	if "`gen'"=="" local gen r_`var'
	areg `var' ib(last).irelto `using', absorb(team)
	capture drop `gen'
	predict `gen', resid
	
	// Extract betas for irelto
	mat b=e(b)
	foreach num of numlist 1/7 {
		replace `gen'=`gen'+b[1,`num'] if irelto==`num'
	}

	sum `var'
	scalar mean_depvar=r(mean)
	sum `gen'
	replace `gen'=`gen'-(r(mean)-scalar(mean_depvar))
}
end

*** Load data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen at_t=ceil(minutes(ed_tc-${begtime})/60)

// Other variables
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers
egen numv=rowtotal(v? v??)

*** Regressions **************************************************************************
qui reg lntdc ${controlvar2}
capture drop xb_lntdc
predict xb_lntdc, xb

foreach var of varlist xb_lntdc age male esi dr3 dl2 {
	residualize `var', using(${controlvar_comp})
}

qui reg lntdc v? v??
predict xbv_lntdc, xb
qui areg xbv_lntdc ib(last).irelto ${controlvar_comp} ${controlvar1}, absorb(team)
estimates store xbv_lntdc
contrast irelto
residualize xbv_lntdc, using(${controlvar_comp} ${controlvar1})
sum r_xbv_lntdc if e(sample), d

/*
Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 166, 135142)   =     227.71
                                                Prob > F          =     0.0000
                                                R-squared         =     0.7762
                                                Adj R-squared     =     0.3850
                                                Root MSE          =     0.1436

------------------------------------------------------------------------------
   xbv_lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   .0027672   .0105774     0.26   0.794    -.0179644    .0234988
          2  |  -.0019538   .0056922    -0.34   0.731    -.0131103    .0092028
          3  |   .0022139   .0046901     0.47   0.637    -.0069787    .0114065
          4  |   .0044941   .0039001     1.15   0.249    -.0031501    .0121383
          5  |   .0040161   .0032174     1.25   0.212      -.00229    .0103222
          6  |   .0004296   .0025729     0.17   0.867    -.0046133    .0054726

------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.76     0.5977
             |
 Denominator |     135142
------------------------------------------------



                          Residuals
-------------------------------------------------------------
      Percentiles      Smallest
 1%     .8365322        .401202
 5%     .9366069       .4206904
10%     .9845399       .4283255       Obs             371,421
25%     1.061219       .4978611       Sum of Wgt.     371,421

50%     1.076944                      Mean           1.078156
                        Largest       Std. Dev.      .0866359
75%     1.085041        1.89863
90%     1.167141       1.919073       Variance       .0075058
95%     1.229063       1.945071       Skewness       .6097955
99%      1.36552        1.96095       Kurtosis       8.766656
*/

qui areg numv ib(last).irelto ${controlvar_comp} ${controlvar1}, absorb(team)
contrast irelto
residualize numv, using(${controlvar_comp} ${controlvar1})
sum r_numv, d

/*
Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 166, 135142)   =     243.94
                                                Prob > F          =     0.0000
                                                R-squared         =     0.7748
                                                Adj R-squared     =     0.3812
                                                Root MSE          =     0.9459

------------------------------------------------------------------------------
        numv |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   .0083012   .0696798     0.12   0.905    -.1282699    .1448723
          2  |  -.0282469   .0374977    -0.75   0.451    -.1017417    .0452479
          3  |   .0010296   .0308968     0.03   0.973    -.0595275    .0615867
          4  |   .0139355   .0256925     0.54   0.588    -.0364214    .0642924
          5  |   .0107653   .0211951     0.51   0.612    -.0307767    .0523073
          6  |  -.0096383   .0169495    -0.57   0.570     -.042859    .0235824

    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
        numv |    410,968     1.01186    1.208426          0          9

------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.64     0.6993
             |
 Denominator |     135142
------------------------------------------------

                          Residuals
-------------------------------------------------------------
      Percentiles      Smallest
 1%    -.5630639      -3.261527
 5%     .0668565      -2.973306
10%     .3805081      -2.718981       Obs             371,421
25%     .8940193      -2.467678       Sum of Wgt.     371,421

50%     1.011014                      Mean            1.01186
                        Largest       Std. Dev.      .5706558
75%     1.059533        5.87021
90%     1.623291       5.933417       Variance       .3256481
95%     2.017548        6.05036       Skewness       .5387659
99%      2.87553       7.080885       Kurtosis       7.933944
*/

tab irelto, gen(nirelto)
capture drop avg_*
foreach var of varlist nirelto? {
    by at_t, sort: egen avg_`var'=mean(`var')
}

foreach var of varlist xb_lntdc age male esi dr3 dl2 numv {
	qui areg `var' avg_nirelto1-avg_nirelto6 ${controlvar_comp}, absorb(team) ///
		vce(cluster visit_td)
	test avg_nirelto1 avg_nirelto2 avg_nirelto3 avg_nirelto4 avg_nirelto5 ///
		avg_nirelto6
	estimates store `var'
	qui sum r_`var', d
	disp as text _n _col(5) "Distribution of residualized `var'"
	disp as text _col(17) "Mean = " as result r(mean)
	disp as text _col(18) "p10 = " as result r(p10)
	disp as text _col(18) "p25 = " as result r(p25)
	disp as text _col(18) "p50 = " as result r(p50)
	disp as text _col(18) "p75 = " as result r(p75)
	disp as text _col(18) "p90 = " as result r(p90)
}

/*
Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.6975
                                                Adj R-squared     =     0.1686
                                                Root MSE          =     0.3471

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
    xb_lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |  -.0084986   .0655981    -0.13   0.897    -.1371254    .1201282
avg_nirelto2 |  -.0059242   .0212548    -0.28   0.780    -.0476012    .0357527
avg_nirelto3 |   .0164597   .0148559     1.11   0.268    -.0126702    .0455896
avg_nirelto4 |  -.0063804   .0135083    -0.47   0.637    -.0328678    .0201071
avg_nirelto5 |   .0074649   .0127031     0.59   0.557    -.0174438    .0323735
avg_nirelto6 |   .0072233   .0123838     0.58   0.560    -.0170592    .0315058

       F(  6,  2740) =    0.44
            Prob > F =    0.8522

    Distribution of residualized xb_lntdc
                Mean = 1.0781859
                 p10 = .85871309
                 p25 = 1.0559353
                 p50 = 1.0881501
                 p75 = 1.1130387
                 p90 = 1.3076354

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.6846
                                                Adj R-squared     =     0.1333
                                                Root MSE          =    18.1959

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
         age |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |   .8512765   3.297017     0.26   0.796    -5.613613    7.316166
avg_nirelto2 |  -.3045074   1.087642    -0.28   0.780    -2.437189    1.828175
avg_nirelto3 |   .4994036   .7837397     0.64   0.524    -1.037377    2.036184
avg_nirelto4 |  -.3320044   .6994374    -0.47   0.635    -1.703482    1.039473
avg_nirelto5 |   .2824802   .6453946     0.44   0.662    -.9830289    1.547989
avg_nirelto6 |  -.0751007   .6210175    -0.12   0.904    -1.292811    1.142609

       F(  6,  2740) =    0.24
            Prob > F =    0.9634

    Distribution of residualized age
                Mean = 47.610631
                 p10 = 33.68922
                 p25 = 44.959953
                 p50 = 47.382
                 p75 = 48.972759
                 p90 = 61.41272

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.6442
                                                Adj R-squared     =     0.0221
                                                Root MSE          =     0.4846

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
        male |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |  -.0494688   .0894128    -0.55   0.580    -.2247922    .1258545
avg_nirelto2 |  -.0082637   .0294679    -0.28   0.779    -.0660453    .0495179
avg_nirelto3 |   .0099177      .0207     0.48   0.632    -.0306714    .0505069
avg_nirelto4 |   .0216365    .018614     1.16   0.245    -.0148625    .0581355
avg_nirelto5 |   .0182943   .0168371     1.09   0.277    -.0147205    .0513091
avg_nirelto6 |    .005342   .0160954     0.33   0.740    -.0262184    .0369024

       F(  6,  2740) =    0.44
            Prob > F =    0.8496
			
    Distribution of residualized male
                Mean = .40069787
                 p10 = -.04538956
                 p25 = .3883343
                 p50 = .40376589
                 p75 = .40571293
                 p90 = .89140344

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.7109
                                                Adj R-squared     =     0.2056
                                                Root MSE          =     0.6953

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
         esi |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |  -.0035814   .1371146    -0.03   0.979    -.2724398     .265277
avg_nirelto2 |  -.0009364    .044329    -0.02   0.983     -.087858    .0859852
avg_nirelto3 |  -.0323352   .0308252    -1.05   0.294    -.0927781    .0281077
avg_nirelto4 |   .0002935   .0274771     0.01   0.991    -.0535843    .0541714
avg_nirelto5 |  -.0272434    .025331    -1.08   0.282    -.0769133    .0224264
avg_nirelto6 |  -.0205337   .0249125    -0.82   0.410     -.069383    .0283155

       F(  6,  2740) =    0.40
            Prob > F =    0.8784

    Distribution of residualized esi
                Mean = 2.8283297
                 p10 = 2.3352745
                 p25 = 2.7960982
                 p50 = 2.8218682
                 p75 = 2.9003975
                 p90 = 3.3163083

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.6470
                                                Adj R-squared     =     0.0299
                                                Root MSE          =     0.4924

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
         dr3 |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |   .1565746   .0922659     1.70   0.090    -.0243432    .3374924
avg_nirelto2 |   .0215816   .0298956     0.72   0.470    -.0370386    .0802017
avg_nirelto3 |    .019117   .0207476     0.92   0.357    -.0215655    .0597995
avg_nirelto4 |   .0093111   .0190388     0.49   0.625    -.0280208    .0466431
avg_nirelto5 |  -.0221201   .0176859    -1.25   0.211     -.056799    .0125589
avg_nirelto6 |   .0001763   .0168203     0.01   0.992    -.0328054     .033158

       F(  6,  2740) =    1.14
            Prob > F =    0.3389
			
    Distribution of residualized dr3
                Mean = .49477332
                 p10 = .0320706
                 p25 = .47880763
                 p50 = .48966584
                 p75 = .51028538
                 p90 = .97547293

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.6236
                                                Adj R-squared     =    -0.0343
                                                Root MSE          =     0.3065

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
         dl2 |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |   .0238195   .0510895     0.47   0.641    -.0763583    .1239974
avg_nirelto2 |  -.0062361    .018556    -0.34   0.737    -.0426213    .0301492
avg_nirelto3 |   .0041295   .0126265     0.33   0.744    -.0206291     .028888
avg_nirelto4 |   .0067223   .0118573     0.57   0.571    -.0165278    .0299724
avg_nirelto5 |   .0103994   .0109437     0.95   0.342    -.0110593    .0318582
avg_nirelto6 |    .008438   .0103887     0.81   0.417    -.0119325    .0288086

       F(  6,  2740) =    0.28
            Prob > F =    0.9451

    Distribution of residualized dl2
                Mean = .10068911
                 p10 = -.02991362
                 p25 = .09534007
                 p50 = .10002041
                 p75 = .10400846
                 p90 = .11413213

Linear regression, absorbing indicators         Number of obs     =    371,421
                                                F( 149,   2740)   =          .
                                                Prob > F          =          .
                                                R-squared         =     0.7139
                                                Adj R-squared     =     0.2137
                                                Root MSE          =     1.0663

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
        numv |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |   .1402982   .1935185     0.72   0.469    -.2391587    .5197552
avg_nirelto2 |  -.0460456   .0643091    -0.72   0.474    -.1721447    .0800536
avg_nirelto3 |    .033523   .0458334     0.73   0.465    -.0563485    .1233946
avg_nirelto4 |   .0135531   .0410167     0.33   0.741    -.0668738    .0939799
avg_nirelto5 |   .0248019   .0397793     0.62   0.533    -.0531986    .1028024
avg_nirelto6 |   .0366071   .0384949     0.95   0.342    -.0388749    .1120891

       F(  6,  2740) =    0.41
            Prob > F =    0.8722

    Distribution of residualized numv
                Mean = 1.0118598
                 p10 = .32885975
                 p25 = .88268131
                 p50 = 1.0058683
                 p75 = 1.0289644
                 p90 = 1.7013934
*/
