/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table 2
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/
	
global begtime clock("1jun2005 00:00","DMYhm")
global controlvar1 
global controlvar2 age age2 male female35 de? v? v?? dr? dl?
global controlvar3 i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed
global controlvar4 i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed i.irelfrom 
global controlvar5 age age2 male female35 de? dr? dl? i.visit_dow i.nvisit_ym ///
	i.ed_hh p? triage_ed i.irelfrom 
global controlvar_comp i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom 	
global controlvar ${controlvar4}
	
*** Load data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers
tab irelto, gen(nirelto)
capture drop at_t
gen at_t=ceil(minutes(ed_tc-${begtime})/60)

*** OLS Regressions (Columns 1 to 6) *****************************************************
foreach num of numlist 1/3 {
	qui reg lntdc ib(last).irelto ${controlvar`num'}
	estimates describe
	sum lntdc if e(sample)
	estimates store reg_lntdc_`num'
}
foreach num of numlist 3/5 {
	qui areg lntdc ib(last).irelto ${controlvar`num'}, absorb(team)
	estimates describe
	sum lntdc if e(sample)
	estimates store areg_lntdc_`num'
}

/*
. regress lntdc ib(last).irelto

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

      Source |       SS       df       MS              Number of obs =  371107
-------------+------------------------------           F(  6,371100) =  452.06
       Model |  2006.43273     6  334.405455           Prob > F      =  0.0000
    Residual |  274516.203371100  .739736467           R-squared     =  0.0073
-------------+------------------------------           Adj R-squared =  0.0072
       Total |  276522.635371106  .745131136           Root MSE      =  .86008

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.6065635   .0276023   -21.98   0.000    -.6606632   -.5524637
          2  |  -.3157226   .0083718   -37.71   0.000     -.332131   -.2993142
          3  |  -.1391523     .00512   -27.18   0.000    -.1491874   -.1291172
          4  |   -.112242   .0046985   -23.89   0.000    -.1214508   -.1030331
          5  |   -.070136   .0044278   -15.84   0.000    -.0788143   -.0614576
          6  |  -.0646713   .0043022   -15.03   0.000    -.0731036   -.0562391

. regress lntdc ib(last).irelto age age2 male female35 de? v? v?? dr? dl?

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

      Source |       SS       df       MS              Number of obs =  371107
-------------+------------------------------           F( 49,371057) = 1766.88
       Model |   52313.682    49  1067.62616           Prob > F      =  0.0000
    Residual |  224208.953371057  .604243966           R-squared     =  0.1892
-------------+------------------------------           Adj R-squared =  0.1891
       Total |  276522.635371106  .745131136           Root MSE      =  .77733

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5469907   .0249512   -21.92   0.000    -.5958944   -.4980871
          2  |  -.2816737   .0075739   -37.19   0.000    -.2965182   -.2668292
          3  |  -.1285696   .0046312   -27.76   0.000    -.1376467   -.1194926
          4  |  -.0917082   .0042506   -21.58   0.000    -.1000393   -.0833771
          5  |  -.0548843   .0040045   -13.71   0.000    -.0627331   -.0470356
          6  |  -.0480691   .0038901   -12.36   0.000    -.0556936   -.0404447

. regress lntdc ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de?  v? v?? dr? dl? p? triage_ed

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

      Source |       SS       df       MS              Number of obs =  371107
-------------+------------------------------           F(172,370934) =  576.66
       Model |  58340.2831   172  339.187692           Prob > F      =  0.0000
    Residual |  218182.352370934  .588197233           R-squared     =  0.2110
-------------+------------------------------           Adj R-squared =  0.2106
       Total |  276522.635371106  .745131136           Root MSE      =  .76694

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5287716   .0247773   -21.34   0.000    -.5773343   -.4802089
          2  |  -.3299078   .0080158   -41.16   0.000    -.3456184   -.3141972
          3  |  -.1612916   .0058276   -27.68   0.000    -.1727136   -.1498696
          4  |   -.111149   .0051931   -21.40   0.000    -.1213273   -.1009707
          5  |  -.0780545   .0049334   -15.82   0.000    -.0877238   -.0683853
          6  |  -.0574684   .0048896   -11.75   0.000    -.0670519   -.0478848

. areg lntdc ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de?  v? v?? dr? dl? p? triage_ed,
  absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

Linear regression, absorbing indicators           Number of obs   =     371107
                                                  F( 172, 134930) =     152.04
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.7818
                                                  Adj R-squared   =     0.3999
                                                  Root MSE        =     0.6687

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   -.715662   .0389665   -18.37   0.000    -.7920356   -.6392885
          2  |  -.4610824   .0120855   -38.15   0.000    -.4847698    -.437395
          3  |  -.2595032   .0088778   -29.23   0.000    -.2769036   -.2421029
          4  |  -.1733229   .0076603   -22.63   0.000    -.1883369   -.1583089
          5  |  -.1198197   .0072169   -16.60   0.000    -.1339647   -.1056747
          6  |  -.0895617   .0070504   -12.70   0.000    -.1033802   -.0757431

. areg lntdc ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? triage_ed v? v?? dr? dl?
  i.irelfrom p?, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

Linear regression, absorbing indicators           Number of obs   =     371107
                                                  F( 195, 134907) =     147.56
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.7853
                                                  Adj R-squared   =     0.4094
                                                  Root MSE        =     0.6634

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5872996   .0499571   -11.76   0.000    -.6852146   -.4893846
          2  |  -.2868705   .0263613   -10.88   0.000    -.3385381   -.2352029
          3  |  -.1230273   .0217014    -5.67   0.000    -.1655616   -.0804929
          4  |  -.0906951   .0180417    -5.03   0.000    -.1260565   -.0553337
          5  |   -.023231   .0148805    -1.56   0.118    -.0523966    .0059346
          6  |  -.0103391    .011898    -0.87   0.385    -.0336589    .0129808

. areg lntdc ib(last).irelto age age2 male female35 de? dr? dl? i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom,
  absorb(team)

    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
       lntdc |    371,107    1.049238    .8632098   -4.60517   10.29842


Linear regression, absorbing indicators         Number of obs     =    371,107
                                                F( 166, 134936)   =     163.81
                                                Prob > F          =     0.0000
                                                R-squared         =     0.7832
                                                Adj R-squared     =     0.4038
                                                Root MSE          =     0.6665

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5835624   .0501896   -11.63   0.000     -.681933   -.4851917
          2  |  -.2868297   .0264837   -10.83   0.000    -.3387371   -.2349222
          3  |  -.1220427   .0218026    -5.60   0.000    -.1647754   -.0793099
          4  |  -.0894686   .0181244    -4.94   0.000    -.1249921   -.0539451
          5  |  -.0217461   .0149493    -1.45   0.146    -.0510465    .0075543
          6  |  -.0100785   .0119528    -0.84   0.399    -.0335057    .0133487
*/

*** Between Regressions (Columns 7 and 8) ************************************************
capture program drop extract_irelto_b
program extract_irelto_b
syntax , gen(string) 
qui {
	mat b=e(b)
	capture drop `gen'
	gen `gen'=.
	foreach num of numlist 1/7 {
		replace `gen'=b[1,`num'] if irelto==`num'
	}
}
end

capture program drop do_avgreg // for bootstrapping purposes
program do_avgreg, rclass
syntax , controlvar(string)
qui {
	foreach var in Q_sb lntdc_Q_resid resid_lntdc avg_* {
		capture drop `var'
	}
	preserve
	qui areg lntdc ib(last).irelto `controlvar', absorb(team)
	extract_irelto_b, gen(Q_sb)
	predict resid_lntdc, resid
	gen lntdc_Q_resid=Q_sb+resid_lntdc
	foreach var of varlist lntdc_Q_resid nirelto? {
		by at_t, sort: egen avg_`var'=mean(`var')
	}
	keep avg_* at_t visit_td
	duplicates drop
	reg avg_lntdc_Q_resid avg_nirelto1-avg_nirelto6
	foreach num of numlist 1/6 {
		return scalar b`num'=_b[avg_nirelto`num']
	}
	restore
}
end

set seed 0
set more off
bootstrap b1=r(b1) b2=r(b2) b3=r(b3) b4=r(b4) b5=r(b5) b6=r(b6), reps(1000) ///
	nowarn: do_avgreg, controlvar(${controlvar})
set seed 0
set more off
bootstrap b1=r(b1) b2=r(b2) b3=r(b3) b4=r(b4) b5=r(b5) b6=r(b6), reps(1000) ///
	nowarn: do_avgreg, controlvar(${controlvar_comp})
qui do_avgreg, controlvar(${controlvar})
sum avg_lntdc if e(sample) [aw=count] 

/*
Linear regression                               Number of obs     =     68,044
                                                F(6, 2740)        =     406.96
                                                Prob > F          =     0.0000
                                                R-squared         =     0.0606
                                                Root MSE          =     .20662

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
avg_lntdc_~d |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |  -.6120235   .0406306   -15.06   0.000    -.6916932   -.5323538
avg_nirelto2 |  -.3247851    .009226   -35.20   0.000    -.3428757   -.3066945
avg_nirelto3 |  -.1387153   .0045817   -30.28   0.000    -.1476992   -.1297314
avg_nirelto4 |  -.0983408   .0045972   -21.39   0.000    -.1073551   -.0893265
avg_nirelto5 |  -.0371841   .0034807   -10.68   0.000    -.0440092    -.030359
avg_nirelto6 |  -.0149972   .0034363    -4.36   0.000    -.0217352   -.0082592
       _cons |   .0050723   .0013157     3.86   0.000     .0024924    .0076522
------------------------------------------------------------------------------
             |   Observed   Bootstrap                         Normal-based
             |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
          b1 |  -.6120235   .0782836    -7.82   0.000    -.7654566   -.4585904
          b2 |  -.3247851   .0329696    -9.85   0.000    -.3894042   -.2601659
          b3 |  -.1387153   .0253949    -5.46   0.000    -.1884884   -.0889422
          b4 |  -.0983408   .0212363    -4.63   0.000    -.1399631   -.0567185
          b5 |  -.0371841   .0173212    -2.15   0.032    -.0711329   -.0032352
          b6 |  -.0149972   .0141761    -1.06   0.290    -.0427818    .0127874
------------------------------------------------------------------------------

Linear regression                               Number of obs     =     68,044
                                                F(6, 2740)        =     447.25
                                                Prob > F          =     0.0000
                                                R-squared         =     0.0637
                                                Root MSE          =     .21588

                           (Std. Err. adjusted for 2,741 clusters in visit_td)
------------------------------------------------------------------------------
             |               Robust
avg_lntdc~d2 |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
avg_nirelto1 |  -.6262507   .0401364   -15.60   0.000    -.7049514   -.5475501
avg_nirelto2 |  -.3443732   .0095656   -36.00   0.000    -.3631297   -.3256166
avg_nirelto3 |  -.1570218   .0047762   -32.88   0.000    -.1663871   -.1476565
avg_nirelto4 |  -.1068593   .0047399   -22.54   0.000    -.1161534   -.0975651
avg_nirelto5 |  -.0467371   .0036206   -12.91   0.000    -.0538365   -.0396377
avg_nirelto6 |  -.0246959   .0035992    -6.86   0.000    -.0317532   -.0176385
       _cons |   .0054385   .0013926     3.91   0.000     .0027078    .0081692
------------------------------------------------------------------------------
             |   Observed   Bootstrap                         Normal-based
             |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
          b1 |  -.6262507   .0780198    -8.03   0.000    -.7791668   -.4733347
          b2 |  -.3443732   .0349557    -9.85   0.000    -.4128851   -.2758612
          b3 |  -.1570218   .0270543    -5.80   0.000    -.2100472   -.1039964
          b4 |  -.1068593   .0223551    -4.78   0.000    -.1506744   -.0630442
          b5 |  -.0467371   .0186135    -2.51   0.012    -.0832189   -.0102553
          b6 |  -.0246959   .0150273    -1.64   0.100    -.0541487     .004757
------------------------------------------------------------------------------

    Variable |     Obs      Weight        Mean   Std. Dev.       Min        Max
-------------+-----------------------------------------------------------------
   avg_lntdc |  68,044      389906    1.074348   .3824277   -4.60517   6.305285
*/
