/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table 3
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed i.irelfrom 
	
*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers

// Patient-adjusted length of stay
gen_census, of(npid) at_from(ed) at_to(dcord) match interval(15)
gen lntdc_ptadj=ln(t_ed_dcord/npidcensus+.01)

*** Regressions **************************************************************************
foreach var of varlist all_c_all admit lntotcost mort30d bounceback lntdc_ptadj { 
	qui areg `var' ib(last).irelto ${controlvar}, absorb(team)	
	estimates describe
	sum `var' if e(sample)
	estimates store reg_`var'
}

/*
. areg all_c_all ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? triage_ed v? v?? dr? dl?
  i.irelfrom p?, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
   all_c_all |    371421    13.51814    11.13465          1        198

Linear regression, absorbing indicators           Number of obs   =     371421
                                                  F( 195, 135113) =     209.12
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8293
                                                  Adj R-squared   =     0.5307
                                                  Root MSE        =     7.6277

------------------------------------------------------------------------------
   all_c_all |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   1.411461   .5619302     2.51   0.012     .3100885    2.512834
          2  |   -.093291   .3024059    -0.31   0.758    -.6860009    .4994189
          3  |  -.0033502   .2491665    -0.01   0.989    -.4917119    .4850115
          4  |   .1669958   .2072133     0.81   0.420    -.2391384    .5731301
          5  |   .2390379   .1709344     1.40   0.162    -.0959903    .5740662
          6  |   .1916521   .1366969     1.40   0.161    -.0762712    .4595755
		  
. areg admit ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? triage_ed v? v?? dr? dl?
  i.irelfrom p?, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       admit |    371421    .2687786    .4433251          0          1

Linear regression, absorbing indicators           Number of obs   =     371421
                                                  F( 195, 135113) =     265.16
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8031
                                                  Adj R-squared   =     0.4587
                                                  Root MSE        =     0.3262

------------------------------------------------------------------------------
       admit |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   .0568271   .0240278     2.37   0.018      .009733    .1039211
          2  |  -.0004154   .0129307    -0.03   0.974    -.0257593    .0249286
          3  |   .0019214   .0106542     0.18   0.857    -.0189606    .0228035
          4  |   .0037518   .0088603     0.42   0.672    -.0136143    .0211179
          5  |  -.0038773   .0073091    -0.53   0.596     -.018203    .0104483
          6  |  -.0066036   .0058451    -1.13   0.259    -.0180598    .0048527

. areg lntotcost ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? triage_ed v? v?? dr? dl?
  i.irelfrom p?, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
   lntotcost |    366219    6.749845    1.480433  -.5108256   14.02519

Linear regression, absorbing indicators           Number of obs   =     366219
                                                  F( 194, 132160) =     284.79
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8094
                                                  Adj R-squared   =     0.4720
                                                  Root MSE        =     1.0758

------------------------------------------------------------------------------
   lntotcost |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |    .208392   .0804783     2.59   0.010     .0506559     .366128
          2  |   .0266117   .0432447     0.62   0.538    -.0581471    .1113705
          3  |   .0090278   .0356052     0.25   0.800    -.0607577    .0788133
          4  |   .0288259   .0295996     0.97   0.330    -.0291889    .0868407
          5  |   .0339731   .0244063     1.39   0.164    -.0138628    .0818089
          6  |  -.0062847   .0194996    -0.32   0.747    -.0445036    .0319342
          
. areg mort30d ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de?  v? v?? dr? dl? p? triage_ed
  i.irelfrom, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
     mort30d |    371421    .0184938    .1347289          0          1

Linear regression, absorbing indicators           Number of obs   =     371421
                                                  F( 195, 135113) =      67.65
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.7434
                                                  Adj R-squared   =     0.2946
                                                  Root MSE        =     0.1132

------------------------------------------------------------------------------
     mort30d |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   -.002549   .0083364    -0.31   0.760    -.0188882    .0137903
          2  |  -.0006837   .0044863    -0.15   0.879    -.0094767    .0081094
          3  |  -.0052479   .0036965    -1.42   0.156    -.0124929    .0019971
          4  |  -.0013259   .0030741    -0.43   0.666    -.0073511    .0046992
          5  |  -.0019218   .0025359    -0.76   0.449    -.0068921    .0030485
          6  |   .0010926   .0020279     0.54   0.590    -.0028822    .0050673

. areg bounceback ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de?  v? v?? dr? dl? p?
  triage_ed i.irelfrom, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
  bounceback |    371421    .0598728    .2372513          0          1

Linear regression, absorbing indicators           Number of obs   =     371421
                                                  F( 195, 135113) =      12.90
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.6204
                                                  Adj R-squared   =    -0.0435
                                                  Root MSE        =     0.2424

------------------------------------------------------------------------------
  bounceback |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.0276071   .0178547    -1.55   0.122     -.062602    .0073878
          2  |  -.0110735   .0096086    -1.15   0.249    -.0299061    .0077592
          3  |  -.0050279    .007917    -0.64   0.525     -.020545    .0104893
          4  |  -.0024837    .006584    -0.38   0.706    -.0153882    .0104208
          5  |   .0011568   .0054312     0.21   0.831    -.0094883    .0118019
          6  |    .000573   .0043434     0.13   0.895      -.00794    .0090859       

. areg lntdc_ptadj ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de?  v? v?? dr? dl? p?
  triage_ed i.irelfrom, absorb(team)
		  
    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    371148    -.903631    .9504287  -8.188689   10.02935

Linear regression, absorbing indicators           Number of obs   =     371148
                                                  F( 195, 134938) =     186.81
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8095
                                                  Adj R-squared   =     0.4760
                                                  Root MSE        =     0.6880

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.1440633   .0516909    -2.79   0.005    -.2453766     -.04275
          2  |   .0150122    .027307     0.55   0.582     -.038509    .0685333
          3  |   .0904198   .0224894     4.02   0.000      .046341    .1344986
          4  |   .0355253   .0187013     1.90   0.057     -.001129    .0721795
          5  |   .0368018   .0154261     2.39   0.017     .0065669    .0670366
          6  |   .0006989   .0123375     0.06   0.955    -.0234823    .0248801
*/
