/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table 4
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed i.irelfrom 

global controlvar_short i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
    v? v?? dr? dl? p? triage_ed 
	
*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

discretize_dta, interval(15) trim
gen_census, of(npid) at_from(ed) at_to(dcord) match interval(15) gens(avg)
gen lntdc_ptadj=ln(t_ed_dcord/avgcensus)
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen irelfrom=ceil(cond(ed_tc>shiftbeg_tc,hours(ed_tc-shiftbeg_tc),.))
replace irelfrom=13 if irelfrom>13&irelfrom!=.
mkspline from=irelfrom, knots(1 3 5 7) cubic

capture drop ipostovl
gen ipostovl=.
replace ipostovl=0 if postovl<=1
replace ipostovl=2 if postovl>=2&postovl!=.

*** Regressions **************************************************************************
qui areg lntdc_ptadj i.ipostovl#ib(last).irelto ${controlvar} ///
	i.ipostovl#c.from?, absorb(team)

/*
    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    333233   -.9261805    1.005049  -6.659294   9.929385

Linear regression, absorbing indicators           Number of obs   =     333233
                                                  F( 185, 115864) =     118.15
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8103
                                                  Adj R-squared   =     0.4545
                                                  Root MSE        =     0.7423

----------------------------------------------------------------------------------
     lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-----------------+----------------------------------------------------------------
 ipostovl#irelto |
            0 1  |  -.1667114   .0675607    -2.47   0.014    -.2991292   -.0342935
            0 2  |   .0148619   .0381031     0.39   0.697    -.0598196    .0895434
            0 3  |   .0497928    .031084     1.60   0.109    -.0111313    .1107168
            0 4  |   .0071539   .0250876     0.29   0.776    -.0420174    .0563251
            0 5  |   .0129489   .0206285     0.63   0.530    -.0274826    .0533804
            0 6  |  -.0165116   .0148619    -1.11   0.267    -.0456407    .0126175
            2 1  |  -.1049434   .1103891    -0.95   0.342    -.3213044    .1114176
            2 2  |   .0549503    .066981     0.82   0.412    -.0763314     .186232
            2 3  |   .0664836   .0557979     1.19   0.233    -.0428794    .1758465
            2 4  |   .0168074   .0506579     0.33   0.740    -.0824812    .1160961
            2 5  |   .0139973   .0444109     0.32   0.753    -.0730475     .101042
            2 6  |   -.026771   .0379232    -0.71   0.480    -.1010999    .0475579
            2 7  |  -.0707874   .0295581    -2.39   0.017    -.1287209    -.012854
*/

qui areg lntdc_ptadj ib(last).irelto ${controlvar_short} from? ///
	if ipostovl==0, absorb(team)
/*
    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    231576   -.9865012     1.01381  -6.659294   9.929385

Linear regression, absorbing indicators           Number of obs   =     231576
                                                  F( 175,  85437) =      96.12
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.8124
                                                  Adj R-squared   =     0.4914
                                                  Root MSE        =     0.7230

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.2289608   .0689576    -3.32   0.001     -.364117   -.0938045
          2  |   .0141453   .0393489     0.36   0.719    -.0629782    .0912689
          3  |   .0368151   .0325278     1.13   0.258    -.0269391    .1005694
          4  |  -.0018549    .025765    -0.07   0.943    -.0523541    .0486444
          5  |   .0093059   .0215165     0.43   0.665    -.0328663    .0514782
          6  |   -.021628   .0160886    -1.34   0.179    -.0531615    .0099055
*/
	
qui areg lntdc_ptadj ib(last).irelto ${controlvar_short} from? ///
	if ipostovl==2, absorb(team)
/*
    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    101657   -.7887693     .970914   -6.39693   9.613767

Linear regression, absorbing indicators           Number of obs   =     101657
                                                  F( 156,  18268) =      23.08
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.9105
                                                  Adj R-squared   =     0.5017
                                                  Root MSE        =     0.6854

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.0027779   .1429633    -0.02   0.984    -.2829995    .2774436
          2  |   .1402011   .0852542     1.64   0.100    -.0269052    .3073074
          3  |   .0993684   .0686304     1.45   0.148    -.0351537    .2338904
          4  |   .0559894   .0577173     0.97   0.332     -.057142    .1691208
          5  |   .0522276   .0469373     1.11   0.266    -.0397739     .144229
          6  |    .028741   .0311488     0.92   0.356    -.0323136    .0897957
*/
