/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table A-1.1
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global controlvar age age2 male female35 de? dr? dl? ///
	i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom 
global controlvar2 age age2 male female35 de? dr? dl? v? v??	
global controlvar_comp i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom
global begtime clock("1jun2005 00:00","DMYhm") 

capture program drop residualize
program residualize
syntax varlist, using(string) [gen(string)]
qui {
	assert wordcount("`varlist'")==1
	local var `varlist'
	if "`gen'"=="" local gen r_`var'
	areg `var' ib(last).irelto `using', absorb(team)
	capture drop `gen'
	predict `gen', resid
	
	// Extract betas for irelto
	mat b=e(b)
	foreach num of numlist 1/7 {
		replace `gen'=`gen'+b[1,`num'] if irelto==`num'
	}

	sum `var'
	scalar mean_depvar=r(mean)
	sum `gen'
	replace `gen'=`gen'-(r(mean)-scalar(mean_depvar))
}
end
	
*** Load data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen at_t=ceil(minutes(ed_tc-${begtime})/60)

// Other variables
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers

*** Assumption 1 *************************************************************************
foreach var of varlist all_c_all admit lntotcost mort30d bounceback {
	qui reg `var' v? v??
	predict xbv_`var', xb
	qui areg xbv_`var' ib(last).irelto ${controlvar}, absorb(team)
	estimates store xbv_`var'
	contrast irelto
	residualize xbv_`var', using(${controlvar})
	qui sum r_xbv_`var' if e(sample), d
	disp as text _n _col(5) "Distribution of residualized `var'"
	disp as text _col(17) "Mean = " as result r(mean)
	disp as text _col(18) "p10 = " as result r(p10)
	disp as text _col(18) "p25 = " as result r(p25)
	disp as text _col(18) "p50 = " as result r(p50)
	disp as text _col(18) "p75 = " as result r(p75)
	disp as text _col(18) "p90 = " as result r(p90)
}
/*
(results xbv_all_c_all are active now)
------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.58     0.7481
             |
 Denominator |     135142
------------------------------------------------

    Distribution of residualized all_c_all
                Mean = 13.882502
                 p10 = 12.154989
                 p25 = 13.568789
                 p50 = 13.87998
                 p75 = 13.983063
                 p90 = 15.457261
				 
(results xbv_admit are active now)
------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.42     0.8668
             |
 Denominator |     135142
------------------------------------------------

    Distribution of residualized admit
                Mean = .27398727
                 p10 = .18609676
                 p25 = .25962096
                 p50 = .27426997
                 p75 = .28040737
                 p90 = .35211542
				 
(results xbv_lntotcost are active now)
------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.44     0.8546
             |
 Denominator |     135142
------------------------------------------------

    Distribution of residualized lntotcost
                Mean = 6.7769487
                 p10 = 6.4873676
                 p25 = 6.7287683
                 p50 = 6.7781639
                 p75 = 6.7975316
                 p90 = 7.0349793
				 
(results xbv_mort30d are active now)
------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        0.79     0.5791
             |
 Denominator |     135142
------------------------------------------------

    Distribution of residualized mort30d
                Mean = .01859269
                 p10 = .00797556
                 p25 = .01696251
                 p50 = .01875697
                 p75 = .01936905
                 p90 = .02699425
				 
(results xbv_bounceback are active now)
------------------------------------------------
             |         df           F        P>F
-------------+----------------------------------
      irelto |          6        1.41     0.2079
             |
 Denominator |     135142
------------------------------------------------

    Distribution of residualized bounceback
                Mean = .05984164
                 p10 = .05312311
                 p25 = .05913435
                 p50 = .05972981
                 p75 = .06062501
                 p90 = .06656957
*/

*** Assumption 2 *************************************************************************
foreach outcome in lntdc all_c_all admit lntotcost mort30d bounceback {
	qui reg `outcome' ${controlvar2}
	capture drop xb_`outcome'
	predict xb_`outcome', xb
	residualize xb_`outcome', using(${controlvar_comp})
}
tab irelto, gen(nirelto)
capture drop avg_*
foreach var of varlist nirelto? {
	by at_t, sort: egen avg_`var'=mean(`var')
}

foreach var of varlist xb_all_c_all xb_admit xb_lntotcost xb_mort30d xb_bounceback {
	qui areg `var' avg_nirelto1-avg_nirelto6 ${controlvar_comp}, absorb(team) ///
		vce(cluster visit_td)
	test avg_nirelto1 avg_nirelto2 avg_nirelto3 avg_nirelto4 avg_nirelto5 ///
		avg_nirelto6
	estimates store `var'
	qui sum r_`var', d
	disp as text _n _col(5) "Distribution of residualized `var'"
	disp as text _col(17) "Mean = " as result r(mean)
	disp as text _col(18) "p10 = " as result r(p10)
	disp as text _col(18) "p25 = " as result r(p25)
	disp as text _col(18) "p50 = " as result r(p50)
	disp as text _col(18) "p75 = " as result r(p75)
	disp as text _col(18) "p90 = " as result r(p90)
}
/*
(results xb_all_c_all are active now)
       F(  6,  2740) =    0.59
            Prob > F =    0.7396

    Distribution of residualized xb_all_c_all
                Mean = 13.882502
                 p10 = 10.277871
                 p25 = 13.320152
                 p50 = 13.88881
                 p75 = 14.253692
                 p90 = 17.428717

(results xb_admit are active now)
       F(  6,  2740) =    0.42
            Prob > F =    0.8688

    Distribution of residualized xb_admit
                Mean = .27398727
                 p10 = .13195582
                 p25 = .24450348
                 p50 = .26996768
                 p75 = .28303698
                 p90 = .41300496

(results xb_lntotcost are active now)
       F(  6,  2740) =    0.47
            Prob > F =    0.8327

    Distribution of residualized xb_lntotcost
                Mean = 6.7772924
                 p10 = 6.2557297
                 p25 = 6.6799765
                 p50 = 6.7662296
                 p75 = 6.8222365
                 p90 = 7.285924

(results xb_mort30d are active now)				 
       F(  6,  2740) =    0.52
            Prob > F =    0.7926

    Distribution of residualized xb_mort30d
                Mean = .01859269
                 p10 = .00337134
                 p25 = .01575767
                 p50 = .01840602
                 p75 = .01977954
                 p90 = .03108888

(results xb_bounceback are active now)				 
       F(  6,  2740) =    0.24
            Prob > F =    0.9622

    Distribution of residualized xb_bounceback
                Mean = .05988301
                 p10 = .04265034
                 p25 = .05697428
                 p50 = .05911357
                 p75 = .06216282
                 p90 = .07542472				 
*/
