/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table A-1.2
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global begtime clock("1jun2005 00:00","DMYhm")
global controlvar age age2 male female35 de? dr? dl? ///
	i.visit_dow i.nvisit_ym i.ed_hh p? triage_ed i.irelfrom 
global controlvar2a age_r age2_r male_r female35_r de?_r dr?_r dl?_r
global controlvar2b age_r age2_r male_r female35_r de?_r dr?_r dl?_r v?_r v??_r
global controlvar_comp i.visit_dow i.nvisit_ym i.ed_hh triage_ed i.irelfrom 
	
*** Program to extract i.irelto beta's ***************************************************
capture program drop extract_irelto_b
program extract_irelto_b
syntax , gen(string) 
qui {
	mat b=e(b)
	capture drop `gen'
	gen `gen'=.
	foreach num of numlist 1/7 {
		replace `gen'=b[1,`num'] if irelto==`num'
	}
}
end

*** Generate data ****************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

capture drop at_t
gen at_t=ceil(minutes(ed_tc-${begtime})/60)

// Other variables
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers

egen consec_shiftid=group(nshiftid)
sum consec_shiftid
drop nshiftid
rename consec_shiftid nshiftid
sum nshiftid
assert r(max)==22501


*** Jack-knife residuals *****************************************************************
tempfile pre_jk_res
save `pre_jk_res', replace
keep lntdc irelto visit_dow nvisit_ym ed_hh age age2 male female35 de? v? v?? dr? dl? ///
	p? triage_ed irelfrom npid nshiftid
global savefile temp_data_table_a-1.2
set more off
local nshiftid=1
qui while `nshiftid'<22501 {
	noi disp as text "nshiftid = `nshiftid'"
	preserve
	qui areg lntdc ib(last).irelto ${controlvar} if nshiftid!=`nshiftid', absorb(npid)
	clear
	set obs 6
	gen irelto=_n
	extract_irelto_b, gen(coeff)
	gen nshiftid=`nshiftid'
	capture append using "${Data}/${savefile}"
	save "${Data}/${savefile}", replace
	restore
	local nshiftid=`nshiftid'+1
}
use `pre_jk_res', clear

qui areg lntdc ib(last).irelto ${controlvar}, absorb(npid)
extract_irelto_b, gen(Q_sb)
predict resid_lntdc, resid
by at_t, sort: egen Q_hr=mean(Q_sb)
by at_t, sort: egen lntdc_hr=mean(resid_lntdc+Q_sb)

merge m:1 nshiftid irelto using "${Data}/${savefile}", nogen keep(master match)
by at_t, sort: egen Q_hr_jk=mean(coeff)

*** Generate predicted LOS based on patient characteristics ******************************
capture drop *xb*
keep lntdc *_hr* visit_dow nvisit_ym ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed irelfrom sb at_t npid irelto nshiftid
disp as text "Variables: " _c
qui foreach var of varlist age age2 male female35 de? dr? dl? v? v?? {
	noi disp as text "`var' " _c
	areg `var' ${controlvar_comp}, absorb(npid)
	predict `var'_r, resid
}

foreach suffix in 2a 2b {
	qui areg lntdc ${controlvar`suffix'}, absorb(irelto) 
	predict xb_lntdc_`suffix', xb
	by at_t, sort: egen lntdc_xb`suffix'_hr=mean(xb_lntdc_`suffix')
}

*** Column 1 *****************************************************************************
reg lntdc_hr Q_hr_jk, vce(cluster at_t)
/*
Linear regression                                      Number of obs =  409352
                                                       F(  1, 63344) =  294.37
                                                       Prob > F      =  0.0000
                                                       R-squared     =  0.0065
                                                       Root MSE      =  .33524

                               (Std. Err. adjusted for 63345 clusters in at_t)
------------------------------------------------------------------------------
             |               Robust
    lntdc_hr |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
     Q_hr_jk |   1.029458   .0600015    17.16   0.000      .911855    1.147061
       _cons |   .0013511   .0019375     0.70   0.486    -.0024463    .0051485
------------------------------------------------------------------------------
*/

*** Column 2 *****************************************************************************
reg lntdc_xb2a_hr Q_hr, vce(cluster at_t)
/*
Linear regression                                      Number of obs =  409375
                                                       F(  1, 63354) =    1.37
                                                       Prob > F      =  0.2424
                                                       R-squared     =  0.0000
                                                       Root MSE      =  .15344

                               (Std. Err. adjusted for 63355 clusters in at_t)
------------------------------------------------------------------------------
             |               Robust
lntdc_xb2a~r |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
        Q_hr |   .0294256   .0251732     1.17   0.242    -.0199139    .0787652
       _cons |   1.050762    .000878  1196.82   0.000     1.049041    1.052483
------------------------------------------------------------------------------
*/

*** Column 3 *****************************************************************************
reg lntdc_xb2b_hr Q_hr, vce(cluster at_t)
/*
Linear regression                                      Number of obs =  409375
                                                       F(  1, 63354) =    0.88
                                                       Prob > F      =  0.3487
                                                       R-squared     =  0.0000
                                                       Root MSE      =  .15705

                               (Std. Err. adjusted for 63355 clusters in at_t)
------------------------------------------------------------------------------
             |               Robust
lntdc_xb2b~r |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
        Q_hr |   .0242289   .0258552     0.94   0.349    -.0264474    .0749052
       _cons |    1.05065   .0008987  1169.08   0.000     1.048889    1.052412
------------------------------------------------------------------------------
*/
