/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table A-1.3
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global controlvar i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? ///
	v? v?? dr? dl? p? triage_ed i.irelfrom 

*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit costs
gen_reltimeext, by(pod npid) posthrs(6) keepmaster
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen relfrom=hours(ed_tc-shiftbeg_tc)
gen irelfrom=ceil(relfrom)+6 // add 6 since factor variables cannot have negative numbers

*** Selection equation *******************************************************************
// Akin to CH=X'\beta+\tilde{CH} in Altonji, Elder, Taber p. 176
mat varratio=J(1,6,0) 
mat varselected=J(1,6,0)
mat varselect_resid=J(1,6,0)
qui foreach num of numlist 1/6 {
	capture drop selected
	capture drop select_resid
	gen selected=irelto==`num'
	qui areg selected ${controlvar}, absorb(team)
	predict select_resid, resid
	sum selected
	local selected_sd=r(sd)
	sum select_resid
	local select_resid_sd=r(sd)
	mat varselected[1,`num']=`selected_sd'^2
	mat varselect_resid[1,`num']=`select_resid_sd'^2
	mat varratio[1,`num']=(`selected_sd'/`select_resid_sd')^2
}
foreach num of numlist 1/6 {
	if `num'==1 disp as text _col(60) "Var(selected)" _n _col(58) ///
		"-----------------" _n  "irelto:" _col(17) "Var(selected)" _col(35) ///
		"Var(select_resid)" _col(58) "Var(select_resid)"
	disp as result _col(3) "`num'" _col(20) string(varselected[1,`num'],"%9.0g") ///
		_col(40) string(varselect_resid[1,`num'],"%9.0g") ///
		_col(62) string(varratio[1,`num'],"%9.0g")
}

/*
                                                           Var(selected)
                                                         -----------------
irelto:         Var(selected)     Var(select_resid)      Var(select_resid)
  1                .0024927            .0006167              4.041778
  2                .0265768            .0038738              6.860568
  3                .074422             .0078373              9.495823
  4                .0895584            .0105321              8.503343
  5                .1019076            .0128706              7.917834
  6                .1085052            .0139117              7.799557
*/

*** Outcome equation *********************************************************************
// Akin to Y*=CH+X'\gamma+\epsilon on same page
qui areg lntdc ib(last).irelto ${controlvar}, absorb(team)
predict lntdc_resid, resid
qui sum lntdc_resid
scalar var_lntdc_resid=r(sd)^2
disp as text "Var(lntdc_resid) = " as result string(var_lntdc_resid,"%9.0g")
predict lntdc_pred, xbd
gen lntdc_proj=lntdc_pred
mat b=e(b)
qui foreach num of numlist 1/6 {
	replace lntdc_proj=lntdc_proj-b[1,`num'] if irelto==`num'
}
qui sum lntdc_proj
scalar var_lntdc_proj=r(sd)^2
disp as text "Var(lntdc_proj) = " as result string(var_lntdc_proj,"%9.0g")
mat projdiff=J(1,6,0)
foreach num of numlist 1/6 {
	qui sum lntdc_proj if irelto==`num'
	local in_lntdc_proj=r(mean)
	qui sum lntdc_proj if irelto!=`num'
	local out_lntdc_proj=r(mean)
	mat projdiff[1,`num']=`in_lntdc_proj'-`out_lntdc_proj'
	if `num'==1 disp as text _col(13) "E[lntdc_proj|irelto==`num'] -" _n ///
		"irelto:" _col(14) "E[lntdc_proj|irelto!=`num']"
	disp as result _col(3) "`num'" _col(20) string(projdiff[1,`num'],"%9.0g")
}

/*
Var(lntdc_resid) = .1599715
Var(lntdc_proj) = .5802086

            E[lntdc_proj|irelto==1] -
irelto:      E[lntdc_proj|irelto!=1]
  1                -.0011097
  2                -.0110275
  3                .002232
  4                -.0038089
  5                -.0329458
  6                -.041919
*/

*** Summarize potential bias *************************************************************
foreach num of numlist 1/6 {
	if `num'==1 disp as text "irelto:" _col(18) "Potential bias"
	disp as result _col(3) "`num'" _col(20) string(varratio[1,`num']* ///
		var_lntdc_resid/var_lntdc_proj*projdiff[1,`num'],"%9.0g")
}
/*
irelto:          Potential bias
  1                -.0012366
  2                -.020859
  3                .0058437
  4                -.00893
  5                -.0719225
  6                -.0901445
  
 Recall results from tables_figures_111713.do:
 
 . areg lntdc ib(last).irelto i.visit_dow i.nvisit_ym i.ed_hh age age2 male female35 de? triage_ed v? v?? dr? dl?
  i.irelfrom p?, absorb(team)

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       lntdc |    371107    1.049238    .8632098   -4.60517   10.29842

Linear regression, absorbing indicators           Number of obs   =     371107
                                                  F( 195, 134907) =     147.56
                                                  Prob > F        =     0.0000
                                                  R-squared       =     0.7853
                                                  Adj R-squared   =     0.4094
                                                  Root MSE        =     0.6634

------------------------------------------------------------------------------
       lntdc |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.5872996   .0499571   -11.76   0.000    -.6852146   -.4893846
          2  |  -.2868705   .0263613   -10.88   0.000    -.3385381   -.2352029
          3  |  -.1230273   .0217014    -5.67   0.000    -.1655616   -.0804929
          4  |  -.0906951   .0180417    -5.03   0.000    -.1260565   -.0553337
          5  |   -.023231   .0148805    -1.56   0.118    -.0523966    .0059346
          6  |  -.0103391    .011898    -0.87   0.385    -.0336589    .0129808

Thus, for the required ratio of selection on unobservables to selection on observables:

irelto:			Potential bias	Estimated coefficient		Ratio
  1				  -0.0012366		-0.5872996			 474.9309397
  2				  -0.020859			-0.2868705			 13.7528405 
  3				  0.0058437			-0.1230273		 	 -21.05298013
  4				  -0.00893			-0.0906951			 10.1562262
  5				  -0.0719225		-0.023231			 0.323000452
  6				  -0.0901445		-0.0103391			 0.11469474
*/
	
