/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table A-5.1
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

*** Program to create matrix for linear combinations *************************************
capture program drop gen_lcmat
program gen_lcmat
syntax , varver(string) diff_lntdc_vals(string) diff_lntdc_knots(string) ///
	[keepvars(string) dc_eos]
qui {
	clear
	local num_diff_lntdc_vals=wordcount("`diff_lntdc_vals'")
	local num_keepvars=wordcount("`keepvars'")
	if "`dc_eos'"=="" set obs `=`num_diff_lntdc_vals'+`num_keepvars''	
	else {
		assert regexm("${`varver'_u_vars}","u_dc")
		assert regexm("${`varver'_w_vars}","W_eos_incensus_sp1")
		set obs `=`num_diff_lntdc_vals'+`num_keepvars'+1'
	}
	assert wordcount("`diff_lntdc_knots'")==3 // Assumes 3 knots (2 splines)
	gen val_u_diff_lntdc_sp1=.
	gen label=""
	local counter=1
	foreach num of numlist `diff_lntdc_vals' {
		replace val_u_diff_lntdc_sp1=`num' if _n==`counter'
		replace label="u_diff_lntdc = "+string(`num') if _n==`counter'
		local counter=`counter'+1
	}
	mkspline temp=val_u_diff_lntdc_sp1, cubic knots(`diff_lntdc_knots')
	rename temp2 val_u_diff_lntdc_sp2
	drop temp1
	local nx_keepvars=0
	if `num_keepvars'>0 foreach var in `keepvars' {
		if !regexm("`var'","#") local usevar `var'
		else {
			local nx_keepvars=`nx_keepvars'+1
			local intx_varlab`nx_keepvars' `var'
			local usevar u_intx`nx_keepvars'
		}
		gen val_`usevar'=1 if _n==`counter'
		replace label = "`var'" if _n==`counter'
		local counter=`counter'+1
	}
	if "`dc_eos'"!="" {
		gen val_W_eos_incensus_sp1=-1 if _n==_N
		gen val_u_dc=1 if _n==_N
		replace label="u_dc_EOS" if _n==_N
	}
	gen label_index=_n
	local num_labels=_N
	reshape long val_, i(label) j(var) string
	foreach num of numlist 1/`nx_keepvars' {
		replace var="`intx_varlab`num''" if var=="u_intx`num'"
	}
	rename val_ val

	preserve
	keep label label_index
	duplicates drop
	tempfile labels
	save `labels', replace
	clear
	local num_u_vars=wordcount("${`varver'_u_vars}") 
	local num_w_vars=wordcount("${`varver'_w_vars}") 
	set obs `=`num_u_vars'+`num_w_vars''
	gen matlab_var=""
	gen var=""
	foreach num of numlist 1/`num_u_vars' {
		replace matlab_var=word("${`varver'_u_vars}",`num') if _n==`num' 
		replace var=word("${`varver'_u_varlabs}",`num') if _n==`num' 
	}
	foreach num of numlist 1/`num_w_vars' {
		replace matlab_var=word("${`varver'_w_vars}",`num') if ///
			_n==`=`num'+`num_u_vars''
		replace var=word("${`varver'_w_varlabs}",`num') if _n==`=`num'+`num_u_vars'' 
	}
	gen var_index=_n
	expand `num_labels'
	by var, sort: gen label_index=_n
	merge m:1 label_index using `labels', assert(match) nogen
	tempfile template
	save `template', replace
	restore

	merge 1:1 label var using `template', assert(using match) nogen
	replace val=0 if val==.
	drop var matlab_var
	order label label_index var_index val
	reshape wide val, i(label_index) j(var_index)
}
end

*** Initialize ***************************************************************************
global interval=5
global delta=.98
global estfile ${Data}/estimates_dp
global keepirelto_range 1 60 
global diff_lntdc_knots -1.5 -.1 .5
global diff_lntdc_vals -1.5 -1 -.5 0 .5
global callmatlab /Applications/MATLAB_R2016a.app/bin/matlab
	// Update to reflect MATLAB application on your computer

*** Prepare data, then export ************************************************************

// Add workload-adjusted LOS to data, for specifications b to e below
use "${Data}/stored_dp_data.dta", clear
merge m:1 nshiftid using "${Data}/nshiftid_sample_xwalk.dta", assert(match master) ///
	keep(match) nogen
make_logit_dta, interval(${interval}) keepvars(lntdc t_ed_dcord) ///
	visits1h lntdc_ptadj
isid nshiftid at_t sb
keep nshiftid at_t sb u_lntdc_ptadj
merge 1:1 nshiftid at_t sb using "${Data}/temp_data_dp.dta", ///
	assert(match master) keep(match) nogen
replace u_lntdc_ptadj=0 if sb==0
save "${Data}/add_u_lntdc_ptadj.dta", replace


foreach varver in a b c d e {
global varver `varver'
use "${Data}/stored_dp_data.dta", clear
keep sb irelto_base
merge 1:m sb using "${Data}/add_u_lntdc_ptadj", ///
	nogen keep(match using)
	// Estimates are on 10% sample of shifts with length of 9 hours; patient visits
	// for these shifts comprise 90% of all observations
replace irelto_base=0 if sb==0
mkspline u_lntdc_ptadj_sp=u_lntdc_ptadj, knots(-.1 1 2) cubic

// Model specification
if "${varver}"=="a" global keepvars u_xbd_lntdc_sp1
else if "${varver}"=="b" global keepvars u_xbd_lntdc_sp1 u_lntdc_ptadj_sp1 
else if "${varver}"=="c" global keepvars u_xbd_lntdc_sp1 u_reldc_h_sp1
else if "${varver}"=="d" ///
	global keepvars u_xbd_lntdc_sp1 u_lntdc_ptadj_sp1 u_reldc_h_sp1 
else if "${varver}"=="e" ///
	global keepvars u_xbd_lntdc_sp1 u_xbd_lntdc_sp2 ///
	u_lntdc_ptadj_sp1 u_reldc_h_sp1 u_reldc_h_sp2
	
global uxline
global lckeepvars_${varver} ${keepvars}
global wline eos(W_incensus_sp1) w(W_incensus_sp1 W_diff_lntdc_sp1 W_eos*) ///
	w1(W_incensus_sp1) w2(W_adjirelto_sp1) 

proc_dp_varlist, prep(u(u_diff_lntdc_sp? ${keepvars}) ${uxline} ${wline}) ///
	estname(${varver})
	
local en ${varver}_
global vars ${`en'u_vars} ${`en'w_vars} ${`en'Ew_vars} ${`en'h_vars} ${`en'Eh_vars}
sort groupid sb
by groupid: gen choicenum=_n
gen wt=1
keep groupid sb wt choice choicenum ${vars}
order groupid sb wt choice choicenum ${vars}
global infile dp_data_for_est.csv
outsheet using "${Data}/${infile}", comma replace

gen_lcmat, varver(${varver}) diff_lntdc_vals(${diff_lntdc_vals}) ///
	diff_lntdc_knots(${diff_lntdc_knots}) keepvars(${lckeepvars_${varver}})
export delimited val* using "${Data}/lcmat.txt", novarnames replace

*** Process in MATLAB ********************************************************************
global estname dp_estimates_l9_${varver}
global outfile dp_para_${varver}.txt
global lcoutfile lcresults_${varver}.txt

local cmd cd Code;
local cmd `cmd' dp_main_fun('${infile}','${outfile}','lncom','lcmat.txt',
local cmd `cmd' 'lcoutfile','${lcoutfile}',
local cmd `cmd' 'delta',${delta},'fvalfile','fvalfile_${varver}.txt')
!"${callmatlab}" -nodisplay -nosplash -nodesktop -r "`cmd'; exit;" 

capture confirm file "${Output}/${outfile}"
while _rc {
	sleep 1000
	capture confirm file "${Output}/${outfile}"
}

*** Save results in Stata .dta file ******************************************************
ext_estimates, estname(${estname}) estfile(${estfile}) ///
	useresults(delta(${delta}) varver(${varver}) ///
	file(${Output}/${outfile})) append replace
}

*** Compile results from multiple specifications *****************************************
tempfile results combined
local started=0
qui foreach varver in a b c d e { 
	noi disp as result "`varver' " _c 
	import delimited "${Output}/lcresults_`varver'.txt", ///
		delim(tab) clear
	keep v1 v2
	scalar N=v2[1]
	scalar groups=v1[1]
	scalar LL=-v2[2]
	rename v1 b_`varver'
	rename v2 se_`varver'
	keep if _n>2
	gen label_index=_n
	save `results', replace
	gen_lcmat, varver(`varver') diff_lntdc_vals(${diff_lntdc_vals}) ///
		diff_lntdc_knots(${diff_lntdc_knots}) keepvars(${lckeepvars_`varver'})
	keep label label_index
	merge 1:1 label_index using `results', assert(match) nogen
	set obs `=_N+3'
	replace label="Observations" if _n==_N-2
	replace label="Groups" if _n==_N-1
	replace label="Log likelihood" if _n==_N
	replace b_`varver'=scalar(N) if _n==_N-2
	replace b_`varver'=scalar(groups) if _n==_N-1
	replace b_`varver'=scalar(LL) if _n==_N
	replace label_index=100 if _n==_N-2
	replace label_index=101 if _n==_N-1
	replace label_index=102 if _n==_N
	if `started' {
		merge 1:1 label using `combined'
		sum label_index if label_index<100&_merge==3
		by _merge label_index, sort: replace label_index=r(max)+_n if _merge==1
		drop _merge
	}
	sort label_index
	save `combined', replace
	local started=1
	local orderline `orderline' b_`varver' se_`varver'
}
order label_index label `orderline'

/*
label_index	label	b_b	se_b	b_h	se_h	b_c	se_c	b_i	se_i	b_j	se_j
1	u_diff_lntdc = -1.5	-2.4063	.1785947	-2.319839	.1785668	-2.289577	.1788795	-2.07171	.1777495	-1.863617	.175391
2	u_diff_lntdc = -1	-1.628875	.1192404	-1.572094	.1192303	-1.549231	.119412	-1.405582	.1186667	-1.264147	.117072
3	u_diff_lntdc = -.5	-.9995003	.0612789	-.9775538	.0613448	-.9459636	.0612206	-.8861076	.0609149	-.7950922	.0599412
4	u_diff_lntdc = 0	-.6655681	.0226138	-.6887439	.022901	-.6162434	.0222667	-.6592882	.0224688	-.5862874	.0218832
5	u_diff_lntdc = .5	-.6349743	.0686931	-.7138352	.068703	-.5673814	.0691509	-.7329451	.0687812	-.6446882	.0684362
6	u_xbd_lntdc_sp1	-.8228185	.0234346	-.9323372	.0344579	-.7446282	.0237868	-.9777943	.034782	-1.137145	.0611428
8	u_lntdc_ptadj_sp1			.0853792	.0219452			.1931808	.0226671	.2164054	.0226389
9	u_reldc_h_sp1					-.2440138	.0171481	-.2894265	.0176769	-.8019664	.0465754
10	u_reldc_h_sp2									1.646889	.1332071
10	u_xbd_lntdc_sp2									.1725817	.043045
100	Observations	792687		792687		792687		792687		792687	
101	Groups	115674		115674		115674		115674		115674	
102	Log likelihood	-77577.04		-77568.27		-77463.99		-77422.82		-77321.02	
*/

*** Compare to log likelihood from fully flexible static model ***************************
use "${Data}/add_u_lntdc_ptadj.dta", clear
keep nshiftid
duplicates drop
merge 1:m nshiftid using "${Data}/stored_dp_data.dta", assert(using match) ///
	keep(match) nogen
prep_est_clogit, noest
tempfile obs
save `obs'
use "${Data}/add_u_lntdc_ptadj.dta", clear
keep nshiftid sb at_t
isid nshiftid sb at_t
merge 1:m nshiftid sb at_t using `obs', assert(using match) keep(match) nogen

clogit choice nodc adjirel? diff? baseirel? c.diff?#c.baseirel? ///
	c.adjirel?#c.cen? cen? xbd_lntdc reldc_sp? c.reldc_sp?#c.adjirel?, ///
	group(groupid) iterate(20)
/*
                                                Number of obs     =    792,687
                                                LR chi2(40)       =  268494.27
                                                Prob > chi2       =     0.0000
Log likelihood = -77071.896                     Pseudo R2         =     0.6353
*/

disp as text "Average probability of choice according to model" _n ///
	"       DP model: " as result exp(-77300.52/115674) _n as text ///
	"   Static model: " as result exp(-77071.896/115674)
/*
Average probability of choice according to model
       DP model: .51259878
   Static model: .51361291
*/
