/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Create Table A-7.3
NOTES: 
- To be run from master_tables_figures.do
- May run individually, but need to run preamble in master_tables_figures.do first
*****************************************************************************************/

global interval=5
global shiftlens 7 8 9 10 12
global arrival_estimates ologit
global discharge_estimates clogit
global nshifttypes_7 9/11
global nshifttypes_8 12/13
global nshifttypes_9 14/35
global nshifttypes_10 1/6
global nshifttypes_12 7/8

*** Generate data ************************************************************************
gen_working_data, poe(sum)
gen_var, visittime elix control outcomes team dem_vit
gen_reltimeext, by(pod npid) posthrs(6) keepmaster

discretize_dta, interval(15) trim
gen_census, of(npid) at_from(ed) at_to(dcord) match interval(15) gens(avg)
gen byte sample=periods<=12*60/${interval}&periods>0&irelto_base<=12*60/${interval}& ///
    irelto_base!=.&shiftlen!=.
gen lntdc_ptadj=ln(t_ed_dcord/avgcensus)
gen irelto=ceil(hours(shiftend_tc-ed_tc))
replace irelto=7 if irelto>7&irelto!=.
gen irelfrom=ceil(cond(ed_tc>shiftbeg_tc,hours(ed_tc-shiftbeg_tc),.))
replace irelfrom=13 if irelfrom>13&irelfrom!=.
mkspline from=irelfrom, knots(1 3 5 7) cubic

*** Regressions of actual discharges *****************************************************
local regline1 ib(last).irelto from?
local regline2 ib(last).irelto from? if postovl<=1
local regline3 ib(last).irelto from? if postovl>=2&postovl!=.
foreach num of numlist 1/3 {
	qui reg lntdc_ptadj `regline`num''
	estimates store lntdc_ptadj_`num'
	estimates describe 
	sum lntdc_ptadj if e(sample)
}

/*
. reg lntdc_ptadj ib(last).irelto from?

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    334783   -.9271585    1.005324  -6.659294   9.929385

      Source |       SS           df       MS      Number of obs   =   334,783
-------------+----------------------------------   F(9, 334773)    =    322.64
       Model |  2909.61373         9  323.290415   Prob > F        =    0.0000
    Residual |   335446.58   334,773  1.00201205   R-squared       =    0.0086
-------------+----------------------------------   Adj R-squared   =    0.0086
       Total |  338356.194   334,782  1.01067618   Root MSE        =     1.001

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   -.232133   .0374867    -6.19   0.000    -.3056058   -.1586602
          2  |  -.0692065   .0188463    -3.67   0.000    -.1061447   -.0322683
          3  |  -.0160891   .0151725    -1.06   0.289    -.0458266    .0136485
          4  |  -.0773727   .0137143    -5.64   0.000    -.1042523   -.0504932
          5  |  -.0518264   .0115411    -4.49   0.000    -.0744467   -.0292061
          6  |  -.0320414   .0077628    -4.13   0.000    -.0472563   -.0168265
		  
. reg lntdc_ptadj ib(last).irelto from? if postovl<=1

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    231576   -.9865012     1.01381  -6.659294   9.929385
 
      Source |       SS           df       MS      Number of obs   =   231,576
-------------+----------------------------------   F(9, 231566)    =    274.66
       Model |  2513.95335         9   279.32815   Prob > F        =    0.0000
    Residual |  235501.211   231,566  1.01699391   R-squared       =    0.0106
-------------+----------------------------------   Adj R-squared   =    0.0105
       Total |  238015.164   231,575  1.02781027   Root MSE        =    1.0085

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.3387547   .0497177    -6.81   0.000       -.4362   -.2413093
          2  |  -.0889963   .0253153    -3.52   0.000    -.1386136   -.0393791
          3  |  -.0267012   .0199294    -1.34   0.180    -.0657622    .0123598
          4  |  -.0758672   .0172802    -4.39   0.000    -.1097359   -.0419985
          5  |  -.0481487   .0143289    -3.36   0.001    -.0762331   -.0200644
          6  |  -.0283795   .0095515    -2.97   0.003    -.0471003   -.0096588

. reg lntdc_ptadj ib(last).irelto from? if postovl>=2&postovl!=.

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
 lntdc_ptadj |    101657   -.7887693     .970914   -6.39693   9.613767

      Source |       SS       df       MS              Number of obs =  101657
-------------+------------------------------           F(  9,101647) =   78.13
       Model |  658.362261     9  73.1513623           Prob > F      =  0.0000
    Residual |  95170.1065101647  .936280525           R-squared     =  0.0069
-------------+------------------------------           Adj R-squared =  0.0068
       Total |  95828.4688101656  .942674006           Root MSE      =  .96762

------------------------------------------------------------------------------
 lntdc_ptadj |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |   .0311023   .0612521     0.51   0.612     -.088951    .1511557
          2  |   .1677982   .0346889     4.84   0.000     .0998085     .235788
          3  |   .1758118   .0281303     6.25   0.000     .1206767    .2309469
          4  |    .086694   .0259824     3.34   0.001     .0357688    .1376192
          5  |   .0459049   .0218718     2.10   0.036     .0030365    .0887733
          6  |   .0130968   .0143564     0.91   0.362    -.0150415    .0412351
*/

**** Simulate discharges *****************************************************************
tempfile simobs master
save `master', replace
local appendsim=0
qui foreach shiftlen of numlist $shiftlens {
	set_global_knots, shiftlen(`shiftlen')
	local numlist ${nshifttypes_`shiftlen'}
	qui foreach nshifttype of numlist `numlist' {
		noi disp as text "nshifttype == `nshifttype': $S_DATE $S_TIME" _n
		use "${Data}/stored_dp_data.dta", clear
		local opt interval(${interval})
		local opt `opt' template(${Data}/sim_int5_d_template)
		local opt `opt' simirelto_range(-60 108)
		local opt `opt' dpirelto_range(1 0) 
		local opt `opt' discharge_estimates(${discharge_estimates}_len`shiftlen') 
		local opt `opt' arrival_estimates(${arrival_estimates}_len`shiftlen'_`nshifttype')
		local opt `opt' cf_from(0) cf_extend(0) cfonly
		local opt `opt' prep_dp_data_opts( if(shiftlen==`shiftlen') ///
			template(${Data}/sim_int5_d_template) nshifttypes(`nshifttype') ///
			arrival_estimates(ologit_len`shiftlen') ///
			xbd_estimates(xbd_lntdc_len`shiftlen') ///
			incensus)
		noi run_sim if shiftlen==`shiftlen'&nshifttype==`nshifttype', `opt'
		if `appendsim' append using `simobs'
		save `simobs', replace
		local appendsim=1
	}
}
sum_sim_data, nocollapse types(sim)
keep sb sim_lntdc_ptadj
merge 1:1 sb using `master', keep(match) nogen

*** Regressions of simulated discharges **************************************************
local regline1 ib(last).irelto from?
local regline2 ib(last).irelto from? if postovl<=1
local regline3 ib(last).irelto from? if postovl>=2&postovl!=.
foreach num of numlist 1/3 {
	qui reg sim_lntdc_ptadj `regline`num''
	estimates store sim_lntdc_ptadj_`num'
	estimates describe 
	sum sim_lntdc_ptadj if e(sample)
}

/*
. reg sim_lntdc_ptadj ib(last).irelto from?

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
sim_lntdc_~j |    334955   -.9203863    1.010992  -4.969813   2.957511

      Source |       SS       df       MS              Number of obs =  334955
-------------+------------------------------           F(  9,334945) =  375.76
       Model |  3417.91344     9   379.76816           Prob > F      =  0.0000
    Residual |  338518.462334945   1.0106688           R-squared     =  0.0100
-------------+------------------------------           Adj R-squared =  0.0100
       Total |  341936.376334954  1.02084577           Root MSE      =  1.0053

------------------------------------------------------------------------------
sim_lntdc_~j |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.2000071   .0374894    -5.34   0.000    -.2734852    -.126529
          2  |  -.0671742   .0189113    -3.55   0.000    -.1042398   -.0301086
          3  |   -.012733     .01523    -0.84   0.403    -.0425834    .0171173
          4  |  -.0518303   .0137696    -3.76   0.000    -.0788183   -.0248423
          5  |  -.0374737   .0115887    -3.23   0.001    -.0601873   -.0147602
          6  |  -.0276339   .0077945    -3.55   0.000    -.0429109   -.0123568
		  
. reg sim_lntdc_ptadj ib(last).irelto from? if postovl<=1

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
sim_lntdc_~j |    231710   -.9730675     1.01116  -4.969813   2.944439

      Source |       SS       df       MS              Number of obs =  231710
-------------+------------------------------           F(  9,231700) =  297.18
       Model |   2706.5451     9  300.727233           Prob > F      =  0.0000
    Residual |  234466.316231700  1.01193921           R-squared     =  0.0114
-------------+------------------------------           Adj R-squared =  0.0114
       Total |  237172.861231709   1.0235807           Root MSE      =   1.006

------------------------------------------------------------------------------
sim_lntdc_~j |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.2403355   .0493632    -4.87   0.000    -.3370861   -.1435849
          2  |  -.0636809     .02524    -2.52   0.012    -.1131507   -.0142112
          3  |  -.0065673    .019875    -0.33   0.741    -.0455218    .0323872
          4  |  -.0438933   .0172344    -2.55   0.011    -.0776724   -.0101142
          5  |  -.0293324   .0142915    -2.05   0.040    -.0573433   -.0013215
          6  |  -.0212462   .0095259    -2.23   0.026    -.0399166   -.0025757
		  
. reg sim_lntdc_ptadj ib(last).irelto from? if postovl>=2&postovl!=.

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
sim_lntdc_~j |    101692   -.7977864    1.000011   -4.85203   2.957511

      Source |       SS       df       MS              Number of obs =  101692
-------------+------------------------------           F(  9,101682) =   89.67
       Model |  794.949188     9  88.3276875           Prob > F      =  0.0000
    Residual |  100157.599101682  .985008157           R-squared     =  0.0079
-------------+------------------------------           Adj R-squared =  0.0078
       Total |  100952.549101691  .992738282           Root MSE      =  .99248

------------------------------------------------------------------------------
sim_lntdc_~j |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
      irelto |
          1  |  -.0533797   .0626704    -0.85   0.394    -.1762129    .0694535
          2  |    .101132   .0355687     2.84   0.004     .0314178    .1708461
          3  |   .1224543   .0288458     4.25   0.000      .065917    .1789916
          4  |    .075045   .0266462     2.82   0.005     .0228188    .1272712
          5  |    .031369   .0224302     1.40   0.162    -.0125939    .0753318
          6  |   .0021645    .014723     0.15   0.883    -.0266924    .0310215		  
*/
