/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Prepare arrival count data
NOTES: 
- Used by estimate_arrivals_count.do and make_figure_a-5.2.do
******************************************************************************************/

global interval=5

gen_working_data, poe(sum)
gen_var, visittime
drop *_c_* *_d_* *_signed_* poeid visitid 
	// Drop POE variables, as only using poe(sum) to select sample
drop nurse res_pa physician destination visit_ym // Drop other string variables
gen_reltimeext, by(npid pod) posthrs(6) keepmaster
discretize_dta, interval(${interval}) trim
gen_reltimeext, by(npid pod) posthrs(6) keepsched keepmaster ///
	interval(5) at(ed)
	// Note by(npid pod) to be consistent with sample definition
	// Add -keepsched- to include possible times for arrivals
gen_census_dense, interval(5) matchlag(1)

foreach var in pod room nroom {
	capture rename `var' `var'_adm
}
name_pods, shift(word(shiftid,1)) time(date(word(shiftid,2),"MDY"))
drop shiftid
gen_var, room
replace ed_hh=hh(ed_tc) // Otherwise ed_hh missing for schedule-only observations
gen shiftend_hh=hh(shiftend_tc)
gen ed_dow=dow(dofc(ed_tc))
gen ed_ym=(year(dofc(ed_tc))-2005)*12+month(dofc(ed_tc))-1
gen byte sample=periods<=12*60/${interval}&periods>0&irelto_base<=12*60/${interval}& ///
	irelto_base!=.&shiftlen!=.	

by ed_t npid, sort: egen visits=total(sample) 
	// Doesn't matter if this or -ed_t npid nshiftid- 
	// (i.e., no duplicates within ed_t npid)
discretize_dta, interval(${interval}) replace 
	// for irelto_base and irelfrom_base of new observations
keep if irelfrom_base>-3*60/${interval}
keep ed_t npid npod nroom nshifttype ed_hh ed_dow ed_ym visits irelfrom_base ///
	irelto_base postovl census shiftlen preovl nshiftid shiftend_hh
duplicates drop
sort nshiftid npid ed_t 
by nshiftid npid: gen visits1h=sum(visits[_n-1])-sum(visits[_n-1-60/${interval}])
gen byte hasvisits1h=visits1h>0
replace visits=3 if visits>3

save "${Data}/arrival_count_data", replace
