/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Generate stored dataset by pulling in various raw text files
NOTES:
*****************************************************************************************/

******************************************************************************************
*** Load and process raw data ************************************************************
******************************************************************************************

*** Data prior to 2011 *******************************************************************
*** Load and append main data by year ****************************************************
tempfile master
qui foreach yr in 05 06 07 08 09 10 11 {
	use "${Raw}/Chan_FY`yr'", clear
	keep sb mrn VISIT_AGE sex esi  TRIAGE_DT TRIAGE_HR TM_IN_DT TIME_IN_EX ///
		DT_DISP_ORD TM_DIS_ORD MD_ASSIGNE physician destination ///
		D_C_DATE D_C_HOUR INP_DOA INP_ADTM VISIT_DATE
	if `yr'!=05 {
		append using `master'
	}
	save `master', replace
}
qui {
	rename VISIT_AGE age
	rename TRIAGE_DT triage_d
	rename TRIAGE_HR triage_t
	rename TM_IN_DT ed_d
	rename TIME_IN_EX ed_t
	rename DT_DISP_ORD dcord_d
	rename TM_DIS_ORD dcord_t
	rename MD_ASSIGNE res_pa
	rename D_C_DATE dc_d
	rename D_C_HOUR dc_t
	rename INP_DOA admit_d
	rename INP_ADTM admit_t
}

*** Merge with pod and nursing data by year **********************************************
gen cummerge=.
qui foreach yr in 05 06 07 08 09 10 11 {
	merge 1:1 sb mrn VISIT_DATE using "${Raw}/FY`yr'_POD", update
	replace _merge=3 if _merge==4
	replace cummerge=_merge if _merge==2|_merge==3
	drop _merge
}
keep if cummerge==3
drop cummerge
qui {
	drop VISIT_YEAR TIME_NURSE
	rename VISIT_DATE visit_dt
	rename NURSE_ASSI nurse
	rename SVS_SBST pod
}
gen visit_td=date(visit_d,"MD20Y")
drop visit_d
format visit_td %td

*** Drop 27 redundant visits (incorrectly have different SBs)
// drop if sb== ...
// Code obscured for confidentiality
gen byte datetype=1
save `master', replace

*** Data from 2011 ***********************************************************************
use "${Data}/Chan_FY11b", clear
keep sb mrn Age Sex esi TriageDate TriageTime DateIn TimeIn ///
	DispDate DispTime MD_Assigned Attending_MD Destination_Disposition ///
	DischargeDate DischargeHour InptAdmissionDate InptAdmissionTime NurseAssigned ///
	Service_Subset_POD VisitDate
	
rename Age age
rename Sex sex
rename TriageDate triage_td
rename TriageTime triage_t
rename DateIn ed_td
rename TimeIn ed_t
rename DispDate dcord_td
rename DispTime dcord_t
rename MD_Assigned res_pa
rename Attending_MD physician
rename Destination_Disposition destination
rename DischargeDate dc_td
rename DischargeHour dc_t
rename InptAdmissionDate admit_td
rename InptAdmissionTime admit_t
rename NurseAssigned nurse
rename Service_Subset_POD pod
rename VisitDate visit_td
gen byte datetype=0

// correct changes in physician names compared to previous data
// Involves 3 physicians
// Code obscured for confidentiality

append using `master'
save `master', replace

*** Data from 2012 ***********************************************************************
use "${Raw}/Chan_FY12", clear
keep sb mrn VISIT_AGE sex esi TRIAGE_DT TRIAGE_HR TM_IN_DT TIME_IN_EX ///
	DT_DISP_ORD TM_DIS_ORD MD_ASSIGNED physician destination D_C_DATE D_C_HOUR ///
	VISIT_DATE INP_DOA INP_ADTM NURSE_ASSIGNED SVS_SBST     

rename VISIT_AGE age
rename TRIAGE_DT triage_td
rename TRIAGE_HR triage_t
rename TM_IN_DT ed_td
rename TIME_IN_EX ed_t
rename DT_DISP_ORD dcord_td
rename TM_DIS_ORD dcord_t
rename MD_ASSIGNED res_pa
rename D_C_DATE dc_td
rename D_C_HOUR dc_t
rename INP_DOA admit_td
rename INP_ADTM admit_t
rename NURSE_ASSIGNED nurse
rename SVS_SBST pod
rename VISIT_DATE visit_td
gen byte datetype=0

// correct changes in physician names compared to previous data
// Involves 4 physicians
// Code obscured for confidentiality

// Delete 6 redundant patient observations
// Code obscured for confidentiality

append using `master'
save `master', replace

******************************************************************************************
*** Subsequent joint processing **********************************************************
******************************************************************************************

*** Transform times **********************************************************************
foreach point in triage ed dcord dc admit {
	gen `point'_ts=string(`point'_t,"%04.0f") if `point'_t!=.
	replace `point'_ts=substr(`point'_ts,1,2)+":"+substr(`point'_ts,3,2) ///
		if `point'_t!=.	
	gen `point'_dt=cond(datetype,`point'_d,string(`point'_td,"%td"))+" "+`point'_ts
	gen double `point'_tc=cond(datetype,clock(`point'_dt,"MD20Yhm"), ///
		clock(`point'_dt,"DM20Yhm"))	
	drop `point'_t `point'_ts `point'_dt `point'_d
}
replace admit_td=dofc(admit_tc) if admit_td==.
drop triage_td ed_td dcord_td dc_td datetype 
format *_td %td
format *_tc %tc

*** Other variables **********************************************************************	
gen byte p1=cond(pod=="ALPHA",1,cond(pod=="",.,0))
gen byte p2=cond(pod=="BRAVO",1,cond(pod=="",.,0))
gen byte p3=cond(pod=="ECNU",1,cond(pod=="",.,0))
gen byte male=sex=="M"
drop sex

*** Assign physician ID's ****************************************************************

tempfile master
save `master', replace
use "${Data}/npid_name_xwalk", clear
rename name physician
keep npid physician
merge 1:m physician using `master', keep(match using) nogen 

save "${Data}/stored_data", replace
