/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Discretize data to estimate models and simulate counterfactuals
NOTES: 
******************************************************************************************/

capture program drop discretize_dta
program discretize_dta 
syntax , [interval(integer 60) trim replace timevars(string)]
qui {
	if "`replace'"=="replace" local gen_rep replace
	else local gen_rep gen
	local begtime clock("1jun2005 00:00","DMYhm")
	
	// Fix times
	capture replace dcord_tc=max(dc_tc,dcord_tc) if dc_tc!=.&dcord_tc!=.& ///
		hours(dcord_tc-ed_tc)<0
		// Not relevant for simulated arrivals
	foreach time in ed dcord `timevars' {
		capture `gen_rep' `time'_t=ceil(minutes(`time'_tc-`begtime')/`interval')	
		// For generating assignment probability, ed_t already exists
	}

	capture `gen_rep' irelto_base=-ceil(-minutes(shiftend_tc-ed_tc)/`interval')+1 // 1/4/16
	capture `gen_rep' irelfrom_base=ceil(minutes(ed_tc-shiftbeg_tc)/`interval')
	capture replace irelfrom_base=13*60/`interval' ///
		if irelfrom_base!=.&irelfrom_base>13*60/`interval'

	// Not relevant for simulated arrivals
	capture `gen_rep' periods=dcord_t-ed_t+1 
	capture `gen_rep' t_ed_dcord_d=cond(periods==1,.3,periods-1)/60*`interval'
	capture `gen_rep' lntdc_ptadj_d=ln(t_ed_dcord_d/npidcensus)
	
	if "`trim'"=="trim" {
		drop if ed_t==.|dcord_t==.|npid==. // All 2277 observations are with missing npid
		capture drop if shiftid=="" // 8252 observations
		capture drop if nshiftid==.
		drop if periods<=0 // 297 observations
		capture drop if dcord_tc<=shiftbeg_tc
		// None of these observations are included in sample anyway
	}
}
end
