/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Compute attending-peer history of shift-hour overlap
NOTES: 
******************************************************************************************/

program gen_cumhx_peer
syntax , [npid(string) peernpid(string) date(string) hour(string)]
qui {
	if "`npid'"=="" local npid npid
	if "`peernpid'"=="" local peernpid peernpid
	if "`date'"=="" local date visit_td
	if "`hour'"=="" local hour ed_hh
	if "`room'"=="" local room room
	else local room
	
	tempfile master xwalk
	save `master', replace
	
	schedule_in_intervals

	// Create peer-attending matches within date-hour-room observations
	keep npid room date hour
	by room date hour, sort: egen count=count(_n)
	keep if count>1
	expand count
	by date hour room npid, sort: gen id=_n
	by date hour room: gen peernpid=npid[count*id]
	drop if npid==peernpid
	drop count id

	// Sort matches to create history
	sort npid peernpid date hour
	by npid peernpid: gen cumhx=_n
	
	// Impute history prior to data
	merge_npid_char, varlist(start_td) npid(npid) gen(attg)
	merge_npid_char, varlist(start_td) npid(peernpid) gen(peer)
	gen predays=max(td(1jun2005)-max(attgstart_td,peerstart_td),0)
	sort npid peernpid date
	by npid peernpid: gen maxcumhx=cumhx[_N]
	by npid peernpid: gen postdays=max(date[_N])-td(31may2005)
	gen impcumhx=cumhx+(predays*maxcumhx/postdays)
	local cumhx cumhx impcumhx
	
	keep npid date hour peernpid `cumhx'

	rename npid `npid'
	rename peernpid `peernpid'
	gen datehour=date+hour/24
	gen datehour_xw=datehour
	drop date hour
	save `xwalk', replace
	
	use `master', clear
	capture drop datehour
	gen datehour=`date'+`hour'/24
	gen datehour_ms=datehour
	nearmrg `npid' `peernpid' using `xwalk', nearvar(datehour) keep(match master) nogen
}
end
