/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Generate working data
NOTES:
******************************************************************************************/

capture program drop gen_working_data
program gen_working_data 
syntax , [poe(string)]
qui {	
	if "`poe'"=="sum" {
		use "${Data}/sum_poe_data", clear
		keep aor npid1 poeid first_*_tc last_*_tc npid_c_all all_* npidpoe
		foreach npid in aor npid1 {
			gen temp_`npid'_c_all=npid_c_all if `npid'
			by poeid, sort: egen `npid'_c_all=min(temp_`npid'_c_all) 
			foreach order in first last {
				gen double temp_`order'_`npid'_signed_tc= ///
					`order'_npid_signed_tc if `npid'
				by poeid: egen double `order'_`npid'_signed_tc= ///
					min(temp_`order'_`npid'_signed_tc) // get rid of missing
			}
		}
		by poeid: egen npid1_npid=max(npid1*npidpoe) // record npid of npid1
		drop aor npid1 *npid_* temp_* npidpoe
		duplicates drop
		merge 1:1 poeid using "${Data}/pan_dta_xwalk", keep(match) nogen
		merge 1:1 sb using "${Data}/stored_data", keep(match) nogen				
	}
	else if "`poe'"=="all" {
		use "${Data}/sum_poe_data", clear
		merge m:1 poeid using "${Data}/pan_dta_xwalk", keep(match) nogen
		merge m:1 sb using "${Data}/stored_data", keep(match) nogen				
	}
	else use "${Data}/stored_data", clear

	replace triage_tc=ed_tc if triage_tc==.
	replace ed_tc=triage_tc if ed_tc==.
	replace dc_tc=dcord_tc if dc_tc==.
	replace dcord_tc=dc_tc if dcord_tc==.

	// Compute durations
	gen t_ed_dcord=hours(dcord_tc-ed_tc)
	if "`poe'"=="sum" {
		gen t_ed_ord=hours(first_all_signed_tc-ed_tc)
		gen t_ed_npid1ord=hours(first_npid1_signed_tc-ed_tc)
		gen t_ed_aorord=hours(first_aor_signed_tc-ed_tc)
		capture gen t_lastord_dcord=hours(dcord_tc-last_all_real_signed_tc)
	}
	replace t_ed_dcord=hours(max(dc_tc,dcord_tc)-ed_tc) if ///
		dc_tc!=.&dcord_tc!=.&t_ed_dcord<0
	capture replace t_lastord_dcord=hours(max(dc_tc,dcord_tc)- ///
		last_all_real_signed_tc) if dc_tc!=.&dcord_tc!=.&t_lastord_dcord<0 		
}
end
