/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Prepare data for conditional logit estimation
******************************************************************************************/

capture program drop prep_est_clogit 
program prep_est_clogit
syntax [if], [est_file(string) noest]
qui {
	noi disp as text _n "Sample: `if'"  
	local time=1
	local run=1
	local regline_touse ${regline}
	if "`prep'"=="" {
		if "`if'"!="" keep `if'
		if "`est_file'"!="" {
			local saveline estfile(`est_file') save
			make_spline, estfile(`est_file') clearall
		}
		make_logit_dta, interval(${interval}) keepvars(lntdc t_ed_dcord xbd_lntdc)
		gen reldc=cond(nodc,0,at_t-lastdc_t)
		make_spline, prefix(adjirel) var(adjirelto) nknots(4) `saveline'
		make_spline, prefix(cen) var(census) nknots(3) `saveline'
		_pctile diff_lntdc, percentiles(5 35 65 95)
		local diff_lntdc_knots
		foreach num of numlist 1/4 {
			local diff_lntdc_knots `diff_lntdc_knots' `=round(r(r`num')*10)/10'
		}
		make_spline, prefix(diff) var(diff_lntdc) knots(`diff_lntdc_knots') `saveline'
		make_spline, prefix(baseirel) var(irelto_base) nknots(4) `saveline'
		make_spline if reldc!=., prefix(reldc_sp) var(reldc) nknots(3) `saveline'
	}
	if "`est'"=="" {
		while `run' {
			noi clogit choice `regline_touse', group(groupid) iterate(20)
			if e(converged) {
				noi estimates describe
				if "`est_file'"!="" {
					noi disp as text _n "  Saving as `est_file'"
					estimates save `est_file', replace
				}
				local run=0
			}
			else if "${regline_bk`=`time''}"!="" {
				noi disp as text _n "Trying again with backup regline" 
				local regline_touse ${regline_bk`time'}
				local time=`time'+1
				local run=1
			}
			else local run=0	
		}
	}
}
end
