/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Programs to export data for Barwick-Pathak implementation in MATLAB or label 
results from MATLAB to store using ext_estimates.ado
******************************************************************************************/

capture program drop prep_varlist 
program prep_varlist
syntax , [w(string) w1(string) w2(string) u(string) u1(string) u2(string) ///
	estname(string) h(string) h1(string) h2(string) eos(string)]
qui {
	if "`eos'"!="" {
		if !regexm("`w'","W_eos*") {
			disp as error "Error: recommend adding 'W_eos*' to -w-"
		}
		if "`eos'"!="null" {
			foreach var of varlist `eos' {
				gen `=regexr("`var'","W_","EW_eos_")'=cond(irelto==1,E`var',0)
				gen `=regexr("`var'","W_","W_eos_")'=0
			}
		}
		foreach var of varlist EW_* {
			if !regexm("`var'","_eos_") replace `var'=0 if irelto==1
		}
	}
	
	foreach type in w h {
		if ("``type'1'"!=""&"``type'2'"=="")|("``type'1'"==""&"``type'2'"!="") {
			disp as error "Error: -`type'1- and -`type'2- must be specified together"
			exit
		}
	}
	foreach type in u_ w_ Ew_ num h_ Eh_ {
		if "`estname'"!="" local `type' `estname'_`type'
		else local `type' `type'
	}
	
	foreach type in w u h {
		local num`type'vars=0
	}
	foreach type in u_ w_ Ew_ num h_ Eh_ {
		global ``type''vars
		global ``type''varlabs
		capture drop `type'var*
	}
	if "`u'"=="" {
		disp as error "Error: -u- splines required"
		exit
	}
	
	
	foreach type in w u h {
		if inlist("`type'","w","h") local numlist 1/2
		else local numlist 1
		local pre2 E
		if "``type''"!="" foreach var of varlist ``type'' {
			local num`type'vars=`num`type'vars'+1
			foreach i of numlist `numlist' {
				gen `pre`i''`type'_var`num`type'vars'=`pre`i''`var'
				label var `pre`i''`type'_var`num`type'vars' `pre`i''`var'
				global ``pre`i''`type'_'vars ${``pre`i''`type'_'vars} ///
					`pre`i''`type'_var`num`type'vars'
				global ``pre`i''`type'_'varlabs ${``pre`i''`type'_'varlabs} `pre`i''`var'
			}
		}
	
		if "``type'1'"!=""&"``type'2'"!="" foreach var1 of varlist ``type'1' {
			foreach var2 of varlist ``type'2' {
				local num`type'vars=`num`type'vars'+1
				foreach i of numlist `numlist' {
					gen `pre`i''`type'_var`num`type'vars'= ///
						`pre`i''`var1'*`pre`i''`var2'
					label var `pre`i''`type'_var`num`type'vars' ///
						"c.`pre`i''`var1'#c.`pre`i''`var2'"
				global ``pre`i''`type'_'vars ${``pre`i''`type'_'vars} ///
					`pre`i''`type'_var`num`type'vars'
				global ``pre`i''`type'_'varlabs ${``pre`i''`type'_'varlabs} ///
					c.`pre`i''`var1'#c.`pre`i''`var2'
				}
			}
		}
	
		scalar `num'`type'vars=`num`type'vars'
	}
}
end

capture program drop label_varlist
program label_varlist
syntax , [estname(string)]
qui {
	foreach type in u_ Ew_ num h_ Eh_ {
		if "`estname'"!="" local `type' `estname'_`type'
		else local `type' `type'
	}
	if "${`u_'vars}"=="" /*|"${`Ew_'vars}"==""*/ {
		disp as error "Error: global macro(s) missing"
		// Note: disabled requirement that ${`Ew_'vars} is nonmissing to allow
		// static models (delta = 0)
		exit
	}
	foreach type in u w h {
		if "`type'"=="w" local nametype Ew
		else local nametype `type'
		if wordcount("${``nametype'_'vars}")!=scalar(`num'`type'vars) {
			disp as error "Error: scalar(num`type'vars) set wrong"
			exit
		}
		if wordcount("${``nametype'_'vars}")!=wordcount("${``nametype'_'varlabs}") {
			disp as error "Error: label and variable counts do not match " ///
				"for ``type'_'"
			exit
		}
	}
	
	local counter=0
	clear
	set obs `=scalar(`num'uvars)+scalar(`num'wvars)+2*scalar(`num'hvars)'
	gen var=""
	gen matlabvar=""
	foreach type in u w h {
		if "`type'"=="u" local nametypes u
		if "`type'"=="w" local nametypes Ew
		if "`type'"=="h" local nametypes h Eh
		foreach nametype in `nametypes' {
			foreach i of numlist 1/`=scalar(`num'`type'vars)' {
				local counter=`counter'+1
				replace var=word("${``nametype'_'varlabs}",`i') if _n==`counter'
				replace matlabvar=word("${``nametype'_'vars}",`i') if _n==`counter'
			}
		}
	}
}
end

capture program drop proc_dp_varlist
program proc_dp_varlist 
syntax , [prep(string) label estname(string)]
qui {
	if "`prep'"!=""&"`label'"!="" {
		noi disp as error "Error: cannot specify both -prep- and -label- in " ///
			"same command"
		exit
	}
	if "`estname'"=="" {
		noi disp as text "Note: global macros without -estname- specified"
	}
	if "`prep'"!="" prep_varlist, `prep' estname(`estname')
	else if "`label'"!="" label_varlist, estname(`estname')
	else {
		noi disp as error "Error: must specify either -prep- or -label-"
		exit
	}
}
end
