/*****************************************************************************************
AUTHOR: David Chan
PURPOSE: Summarize simulated data in counterfactuals
******************************************************************************************/

capture program drop sum_sim_data
program sum_sim_data
syntax , [nocollapse interval(integer 60) truncate_irelto_h(integer -4) ///
	census_interval(integer 0) types(string)]
// interval: Allow summarization to occur at specified interval (default is hour)
qui {
	preserve
	if "`types'"!="" {
		local types : list uniq types
		local testtypes real sim
		local testtypes : list types - testtypes
		assert "`testtypes'"==""
	}
	if "`types'"=="" local types real sim
	capture d sample
	if _rc==0 local sample sample
	local potential_sumvars t_ed_dcord lntdc lntdc_ptadj avgcensus diff_lntdc wtobs
	local sumvars `potential_sumvars' 
	foreach sumvar in `sumvars' {
		foreach type in `types' {
			local keepsumvars `keepsumvars' `type'_`sumvar'
		}
	}
	local min_irelto=`truncate_irelto_h'*60/${interval}
	if `census_interval'==0 local census_interval=${interval}
	
	if regexm("`types'","sim") assert ed_t+period-1==at_t
	
	foreach var in `keepsumvars' int_irelto_base {
		capture drop `var'
	}
	if regexm("`types'","sim") gen sim_dcord_t=cond(sample,at_t,dcord_t)
	if regexm("`types'","real") rename dcord_t real_dcord_t

	foreach p in `types' {
		gen `p'_dcirelto=irelto_base-(`p'_dcord_t-ed_t)
		gen `p'_periods=`p'_dcord_t-ed_t+1
		gen `p'_t_ed_dcord=cond(`p'_periods==1,.5,`p'_periods-1)/60*${interval}
		gen `p'_lntdc=ln(`p'_t_ed_dcord)
		if regexm("`sumvars'","avgcensus")|regexm("`sumvars'","lntdc_ptadj") ///
			gen_census, of(nshiftid) at_from(ed) at_to(`p'_dcord) exact ///
			to(`p'_dcord) match gens(`p'_avg) interval(`census_interval') _t
		if regexm("`sumvars'","lntdc_ptadj") ///
			gen `p'_lntdc_ptadj=ln(`p'_t_ed_dcord/`p'_avgcensus)
		if regexm("`sumvars'","diff_lntdc") ///
			gen `p'_diff_lntdc=`p'_lntdc-xbd_lntdc
	}
	
	if "`collapse'"=="" {
		by nshiftid, sort: gen newshift=_n==1
		egen numshifts=total(newshift)
		sum numshifts
		scalar numshifts=r(mean) // Can be used to normalize wtobs to number of shifts
		gen int_irelto_base=ceil(irelto_base*${interval}/`interval')
		sort `sample' int_irelto_base

		capture d notpost
		if _rc==0 assert sim_dcirelto<`min_irelto' if !notpost
		foreach p in `types' {
			by `sample' int_irelto_base: ///
				egen `p'_wtobs=total(`p'_dcirelto>=`min_irelto')
			foreach var in `sumvars' {
				if !regexm("`var'","wtobs") {
					rename `p'_`var' temp
					by `sample' int_irelto_base: egen `p'_`var'= ///
						total(temp*(`p'_dcirelto>=`min_irelto')/`p'_wtobs)
					drop temp
				}
			}
			replace `p'_wtobs=`p'_wtobs/scalar(numshifts)
		}

		keep int_irelto_base `sample' `keepsumvars' 
		duplicates drop
	}
	restore,not
}
end
